# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: canvas_generated/messages/events.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from canvas_generated.messages import effects_pb2 as canvas__generated_dot_messages_dot_effects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&canvas_generated/messages/events.proto\x12\x06\x63\x61nvas\x1a\'canvas_generated/messages/effects.proto\"^\n\x05\x45vent\x12\x1f\n\x04type\x18\x01 \x01(\x0e\x32\x11.canvas.EventType\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x13\n\x0btarget_type\x18\x04 \x01(\t\"A\n\rEventResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1f\n\x07\x65\x66\x66\x65\x63ts\x18\x02 \x03(\x0b\x32\x0e.canvas.Effect*\xe5\xb8\x02\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x1f\n\x1b\x41LLERGY_INTOLERANCE_CREATED\x10\x01\x12\x1f\n\x1b\x41LLERGY_INTOLERANCE_UPDATED\x10\x02\x12\x18\n\x14\x41PPOINTMENT_CANCELED\x10\x04\x12\x1a\n\x16\x41PPOINTMENT_CHECKED_IN\x10\x05\x12\x17\n\x13\x41PPOINTMENT_CREATED\x10\x06\x12\x19\n\x15\x41PPOINTMENT_NO_SHOWED\x10\x07\x12\x1b\n\x17\x41PPOINTMENT_RESCHEDULED\x10\x08\x12\x18\n\x14\x41PPOINTMENT_RESTORED\x10\t\x12\x17\n\x13\x41PPOINTMENT_UPDATED\x10\n\x12\x1d\n\x19\x42ILLING_LINE_ITEM_CREATED\x10\x0b\x12\x1d\n\x19\x42ILLING_LINE_ITEM_UPDATED\x10\x0c\x12\x16\n\x12\x43ONDITION_ASSESSED\x10\r\x12\x15\n\x11\x43ONDITION_CREATED\x10\x0e\x12\x16\n\x12\x43ONDITION_RESOLVED\x10\x0f\x12\x15\n\x11\x43ONDITION_UPDATED\x10\x10\x12\x13\n\x0f\x43ONSENT_CREATED\x10\x11\x12\x13\n\x0f\x43ONSENT_DELETED\x10\x12\x12\x13\n\x0f\x43ONSENT_UPDATED\x10\x13\x12\x14\n\x10\x43OVERAGE_CREATED\x10\x14\x12\x14\n\x10\x43OVERAGE_UPDATED\x10\x15\x12\x15\n\x11\x45NCOUNTER_CREATED\x10\x16\x12\x15\n\x11\x45NCOUNTER_UPDATED\x10\x17\x12\x1a\n\x16IMAGING_REPORT_CREATED\x10\x1a\x12\x1a\n\x16IMAGING_REPORT_UPDATED\x10\x1b\x12\x18\n\x14IMMUNIZATION_CREATED\x10\x1c\x12\"\n\x1eIMMUNIZATION_STATEMENT_CREATED\x10\x1d\x12\"\n\x1eIMMUNIZATION_STATEMENT_UPDATED\x10\x1e\x12\x18\n\x14IMMUNIZATION_UPDATED\x10\x1f\x12\x17\n\x13INSTRUCTION_CREATED\x10 \x12\x17\n\x13INSTRUCTION_UPDATED\x10!\x12\x15\n\x11INTERVIEW_CREATED\x10\"\x12\x15\n\x11INTERVIEW_UPDATED\x10#\x12\x15\n\x11LAB_ORDER_CREATED\x10$\x12\x15\n\x11LAB_ORDER_UPDATED\x10%\x12\x16\n\x12LAB_REPORT_CREATED\x10&\x12\x16\n\x12LAB_REPORT_UPDATED\x10\'\x12 \n\x1cMEDICATION_LIST_ITEM_CREATED\x10(\x12 \n\x1cMEDICATION_LIST_ITEM_UPDATED\x10)\x12\x13\n\x0fMESSAGE_CREATED\x10*\x12 \n\x1cMESSAGE_TRANSMISSION_CREATED\x10\x35\x12 \n\x1cMESSAGE_TRANSMISSION_UPDATED\x10\x38\x12\x13\n\x0fPATIENT_CREATED\x10+\x12\x13\n\x0fPATIENT_UPDATED\x10,\x12\x18\n\x14PRESCRIPTION_CREATED\x10-\x12\x18\n\x14PRESCRIPTION_UPDATED\x10.\x12\x1b\n\x17REFERRAL_REPORT_CREATED\x10/\x12\x1b\n\x17REFERRAL_REPORT_UPDATED\x10\x30\x12\x11\n\rSTAFF_CREATED\x10\x31\x12\x11\n\rSTAFF_UPDATED\x10\x32\x12\x18\n\x14TASK_COMMENT_CREATED\x10\x33\x12\x10\n\x0cTASK_CREATED\x10\x36\x12\x18\n\x14TASK_LABELS_ADJUSTED\x10\x37\x12\x10\n\x0cTASK_UPDATED\x10\x39\x12\x16\n\x12VITAL_SIGN_CREATED\x10:\x12\x16\n\x12VITAL_SIGN_UPDATED\x10;\x12\x08\n\x04\x43RON\x10<\x12 \n\x1c\x43\x41RE_TEAM_MEMBERSHIP_CREATED\x10=\x12 \n\x1c\x43\x41RE_TEAM_MEMBERSHIP_UPDATED\x10>\x12 \n\x1c\x43\x41RE_TEAM_MEMBERSHIP_DELETED\x10?\x12#\n\x1fNOTE_STATE_CHANGE_EVENT_CREATED\x10@\x12#\n\x1fNOTE_STATE_CHANGE_EVENT_UPDATED\x10\x41\x12\x1b\n\x17PATIENT_ADDRESS_CREATED\x10\x42\x12\x1b\n\x17PATIENT_ADDRESS_UPDATED\x10\x43\x12\x1b\n\x17PATIENT_ADDRESS_DELETED\x10\x44\x12\"\n\x1ePATIENT_CONTACT_PERSON_CREATED\x10\x45\x12\"\n\x1ePATIENT_CONTACT_PERSON_UPDATED\x10\x46\x12\"\n\x1ePATIENT_CONTACT_PERSON_DELETED\x10G\x12!\n\x1dPATIENT_CONTACT_POINT_CREATED\x10H\x12!\n\x1dPATIENT_CONTACT_POINT_UPDATED\x10I\x12!\n\x1dPATIENT_CONTACT_POINT_DELETED\x10J\x12\x1d\n\x19PROTOCOL_OVERRIDE_CREATED\x10K\x12\x1d\n\x19PROTOCOL_OVERRIDE_UPDATED\x10L\x12\x1d\n\x19PROTOCOL_OVERRIDE_DELETED\x10M\x12\x18\n\x14TASK_COMMENT_UPDATED\x10N\x12\x18\n\x14TASK_COMMENT_DELETED\x10O\x12\x12\n\x0e\x44\x45VICE_CREATED\x10P\x12\x12\n\x0e\x44\x45VICE_UPDATED\x10Q\x12\x17\n\x13OBSERVATION_CREATED\x10R\x12\x17\n\x13OBSERVATION_UPDATED\x10S\x12\x1a\n\x16\x44\x45TECTED_ISSUE_CREATED\x10T\x12\x1a\n\x16\x44\x45TECTED_ISSUE_UPDATED\x10U\x12\x0f\n\x0bTASK_CLOSED\x10V\x12\x12\n\x0eTASK_COMPLETED\x10W\x12\x19\n\x15TASK_METADATA_CREATED\x10`\x12\x19\n\x15TASK_METADATA_UPDATED\x10\x61\x12#\n\x1f\x44\x45TECTED_ISSUE_EVIDENCE_CREATED\x10X\x12#\n\x1f\x44\x45TECTED_ISSUE_EVIDENCE_UPDATED\x10Y\x12\x13\n\x0fSTAFF_ACTIVATED\x10Z\x12\x15\n\x11STAFF_DEACTIVATED\x10[\x12\x1f\n\x1b\x43OMPOUND_MEDICATION_CREATED\x10\\\x12\x1f\n\x1b\x43OMPOUND_MEDICATION_UPDATED\x10]\x12\x1b\n\x17\x41PPOINTMENT_LABEL_ADDED\x10^\x12\x1d\n\x19\x41PPOINTMENT_LABEL_REMOVED\x10_\x12\x19\n\x15PRE_COMMAND_ORIGINATE\x10\x64\x12\x1a\n\x16POST_COMMAND_ORIGINATE\x10\x65\x12\x16\n\x12PRE_COMMAND_UPDATE\x10\x66\x12\x17\n\x13POST_COMMAND_UPDATE\x10g\x12\x16\n\x12PRE_COMMAND_COMMIT\x10h\x12\x17\n\x13POST_COMMAND_COMMIT\x10i\x12\x16\n\x12PRE_COMMAND_DELETE\x10j\x12\x17\n\x13POST_COMMAND_DELETE\x10k\x12\x1e\n\x1aPRE_COMMAND_ENTER_IN_ERROR\x10l\x12\x1f\n\x1bPOST_COMMAND_ENTER_IN_ERROR\x10m\x12\x1e\n\x1aPRE_COMMAND_EXECUTE_ACTION\x10n\x12\x1f\n\x1bPOST_COMMAND_EXECUTE_ACTION\x10o\x12#\n\x1fPOST_COMMAND_INSERTED_INTO_NOTE\x10p\x12)\n$SSO__PROCESS_ADDITIONAL_REQUEST_DATA\x10\x96\x01\x12!\n\x1cSSO__GET_POST_LOGIN_REDIRECT\x10\x97\x01\x12\'\n\"ASSESS_COMMAND__CONDITION_SELECTED\x10\xc8\x01\x12\x31\n,MEDICATION_STATEMENT__MEDICATION__PRE_SEARCH\x10\xc9\x01\x12\x32\n-MEDICATION_STATEMENT__MEDICATION__POST_SEARCH\x10\xca\x01\x12/\n*MEDICATION_STATEMENT__MEDICATION__SELECTED\x10\xcb\x01\x12/\n*ADJUST_PRESCRIPTION_COMMAND__PRE_ORIGINATE\x10\xd0\x0f\x12\x30\n+ADJUST_PRESCRIPTION_COMMAND__POST_ORIGINATE\x10\xd1\x0f\x12,\n\'ADJUST_PRESCRIPTION_COMMAND__PRE_UPDATE\x10\xd2\x0f\x12-\n(ADJUST_PRESCRIPTION_COMMAND__POST_UPDATE\x10\xd3\x0f\x12,\n\'ADJUST_PRESCRIPTION_COMMAND__PRE_COMMIT\x10\xd4\x0f\x12-\n(ADJUST_PRESCRIPTION_COMMAND__POST_COMMIT\x10\xd5\x0f\x12,\n\'ADJUST_PRESCRIPTION_COMMAND__PRE_DELETE\x10\xd6\x0f\x12-\n(ADJUST_PRESCRIPTION_COMMAND__POST_DELETE\x10\xd7\x0f\x12\x34\n/ADJUST_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR\x10\xd8\x0f\x12\x35\n0ADJUST_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR\x10\xd9\x0f\x12\x34\n/ADJUST_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION\x10\xda\x0f\x12\x35\n0ADJUST_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION\x10\xdb\x0f\x12\x39\n4ADJUST_PRESCRIPTION_COMMAND__POST_INSERTED_INTO_NOTE\x10\xe4\x0f\x12\x33\n.ADJUST_PRESCRIPTION_COMMAND__AVAILABLE_ACTIONS\x10\xe7\x0f\x12\x30\n+ADJUST_PRESCRIPTION__PRESCRIBE__POST_SEARCH\x10\xdc\x0f\x12/\n*ADJUST_PRESCRIPTION__PRESCRIBE__PRE_SEARCH\x10\xdd\x0f\x12\x31\n,ADJUST_PRESCRIPTION__INDICATIONS__PRE_SEARCH\x10\xde\x0f\x12\x32\n-ADJUST_PRESCRIPTION__INDICATIONS__POST_SEARCH\x10\xdf\x0f\x12.\n)ADJUST_PRESCRIPTION__PHARMACY__PRE_SEARCH\x10\xe0\x0f\x12/\n*ADJUST_PRESCRIPTION__PHARMACY__POST_SEARCH\x10\xe1\x0f\x12:\n5ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__PRE_SEARCH\x10\xe2\x0f\x12;\n6ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__POST_SEARCH\x10\xe3\x0f\x12:\n5ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__PRE_SEARCH\x10\xe5\x0f\x12;\n6ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__POST_SEARCH\x10\xe6\x0f\x12\x30\n+ADJUST_PRESCRIPTION__PRESCRIBER__PRE_SEARCH\x10\xe9\x0f\x12\x31\n,ADJUST_PRESCRIPTION__PRESCRIBER__POST_SEARCH\x10\xea\x0f\x12#\n\x1e\x41LLERGY_COMMAND__PRE_ORIGINATE\x10\xa0\x1f\x12$\n\x1f\x41LLERGY_COMMAND__POST_ORIGINATE\x10\xa1\x1f\x12 \n\x1b\x41LLERGY_COMMAND__PRE_UPDATE\x10\xa2\x1f\x12!\n\x1c\x41LLERGY_COMMAND__POST_UPDATE\x10\xa3\x1f\x12 \n\x1b\x41LLERGY_COMMAND__PRE_COMMIT\x10\xa4\x1f\x12!\n\x1c\x41LLERGY_COMMAND__POST_COMMIT\x10\xa5\x1f\x12 \n\x1b\x41LLERGY_COMMAND__PRE_DELETE\x10\xa6\x1f\x12!\n\x1c\x41LLERGY_COMMAND__POST_DELETE\x10\xa7\x1f\x12(\n#ALLERGY_COMMAND__PRE_ENTER_IN_ERROR\x10\xa8\x1f\x12)\n$ALLERGY_COMMAND__POST_ENTER_IN_ERROR\x10\xa9\x1f\x12(\n#ALLERGY_COMMAND__PRE_EXECUTE_ACTION\x10\xaa\x1f\x12)\n$ALLERGY_COMMAND__POST_EXECUTE_ACTION\x10\xab\x1f\x12-\n(ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE\x10\xae\x1f\x12\'\n\"ALLERGY_COMMAND__AVAILABLE_ACTIONS\x10\xaf\x1f\x12!\n\x1c\x41LLERGY__ALLERGY__PRE_SEARCH\x10\xac\x1f\x12\"\n\x1d\x41LLERGY__ALLERGY__POST_SEARCH\x10\xad\x1f\x12\"\n\x1d\x41SSESS_COMMAND__PRE_ORIGINATE\x10\xd8\x36\x12#\n\x1e\x41SSESS_COMMAND__POST_ORIGINATE\x10\xd9\x36\x12\x1f\n\x1a\x41SSESS_COMMAND__PRE_UPDATE\x10\xda\x36\x12 \n\x1b\x41SSESS_COMMAND__POST_UPDATE\x10\xdb\x36\x12\x1f\n\x1a\x41SSESS_COMMAND__PRE_COMMIT\x10\xdc\x36\x12 \n\x1b\x41SSESS_COMMAND__POST_COMMIT\x10\xdd\x36\x12\x1f\n\x1a\x41SSESS_COMMAND__PRE_DELETE\x10\xde\x36\x12 \n\x1b\x41SSESS_COMMAND__POST_DELETE\x10\xdf\x36\x12\'\n\"ASSESS_COMMAND__PRE_ENTER_IN_ERROR\x10\xe0\x36\x12(\n#ASSESS_COMMAND__POST_ENTER_IN_ERROR\x10\xe1\x36\x12\'\n\"ASSESS_COMMAND__PRE_EXECUTE_ACTION\x10\xe2\x36\x12(\n#ASSESS_COMMAND__POST_EXECUTE_ACTION\x10\xe3\x36\x12,\n\'ASSESS_COMMAND__POST_INSERTED_INTO_NOTE\x10\xe6\x36\x12&\n!ASSESS_COMMAND__AVAILABLE_ACTIONS\x10\xe7\x36\x12#\n\x1e\x41SSESS__CONDITION__POST_SEARCH\x10\xe4\x36\x12\"\n\x1d\x41SSESS__CONDITION__PRE_SEARCH\x10\xe5\x36\x12/\n*CANCEL_PRESCRIPTION_COMMAND__PRE_ORIGINATE\x10\xc0>\x12\x30\n+CANCEL_PRESCRIPTION_COMMAND__POST_ORIGINATE\x10\xc1>\x12,\n\'CANCEL_PRESCRIPTION_COMMAND__PRE_UPDATE\x10\xc2>\x12-\n(CANCEL_PRESCRIPTION_COMMAND__POST_UPDATE\x10\xc3>\x12,\n\'CANCEL_PRESCRIPTION_COMMAND__PRE_COMMIT\x10\xc4>\x12-\n(CANCEL_PRESCRIPTION_COMMAND__POST_COMMIT\x10\xc5>\x12,\n\'CANCEL_PRESCRIPTION_COMMAND__PRE_DELETE\x10\xc6>\x12-\n(CANCEL_PRESCRIPTION_COMMAND__POST_DELETE\x10\xc7>\x12\x34\n/CANCEL_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR\x10\xc8>\x12\x35\n0CANCEL_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR\x10\xc9>\x12\x34\n/CANCEL_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION\x10\xca>\x12\x35\n0CANCEL_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION\x10\xcb>\x12\x39\n4CANCEL_PRESCRIPTION_COMMAND__POST_INSERTED_INTO_NOTE\x10\xce>\x12\x33\n.CANCEL_PRESCRIPTION_COMMAND__AVAILABLE_ACTIONS\x10\xcf>\x12;\n6CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__PRE_SEARCH\x10\xcc>\x12<\n7CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__POST_SEARCH\x10\xcd>\x12\x30\n+CHART_SECTION_REVIEW_COMMAND__PRE_ORIGINATE\x10\xa8\x46\x12\x31\n,CHART_SECTION_REVIEW_COMMAND__POST_ORIGINATE\x10\xa9\x46\x12\x35\n0CHART_SECTION_REVIEW_COMMAND__PRE_ENTER_IN_ERROR\x10\xaa\x46\x12\x36\n1CHART_SECTION_REVIEW_COMMAND__POST_ENTER_IN_ERROR\x10\xab\x46\x12\x35\n0CHART_SECTION_REVIEW_COMMAND__PRE_EXECUTE_ACTION\x10\xac\x46\x12\x36\n1CHART_SECTION_REVIEW_COMMAND__POST_EXECUTE_ACTION\x10\xad\x46\x12\x34\n/CHART_SECTION_REVIEW_COMMAND__AVAILABLE_ACTIONS\x10\xae\x46\x12&\n CLIPBOARD_COMMAND__PRE_ORIGINATE\x10\x88\x9e\x03\x12\'\n!CLIPBOARD_COMMAND__POST_ORIGINATE\x10\x89\x9e\x03\x12#\n\x1d\x43LIPBOARD_COMMAND__PRE_UPDATE\x10\x8a\x9e\x03\x12$\n\x1e\x43LIPBOARD_COMMAND__POST_UPDATE\x10\x8b\x9e\x03\x12#\n\x1d\x43LIPBOARD_COMMAND__PRE_COMMIT\x10\x8c\x9e\x03\x12$\n\x1e\x43LIPBOARD_COMMAND__POST_COMMIT\x10\x8d\x9e\x03\x12#\n\x1d\x43LIPBOARD_COMMAND__PRE_DELETE\x10\x8e\x9e\x03\x12$\n\x1e\x43LIPBOARD_COMMAND__POST_DELETE\x10\x8f\x9e\x03\x12+\n%CLIPBOARD_COMMAND__PRE_ENTER_IN_ERROR\x10\x90\x9e\x03\x12,\n&CLIPBOARD_COMMAND__POST_ENTER_IN_ERROR\x10\xf9\xa5\x03\x12+\n%CLIPBOARD_COMMAND__PRE_EXECUTE_ACTION\x10\xe2\xad\x03\x12,\n&CLIPBOARD_COMMAND__POST_EXECUTE_ACTION\x10\xcb\xb5\x03\x12\x30\n*CLIPBOARD_COMMAND__POST_INSERTED_INTO_NOTE\x10\xcc\xb5\x03\x12*\n$CLIPBOARD_COMMAND__AVAILABLE_ACTIONS\x10\xcd\xb5\x03\x12&\n!CLOSE_GOAL_COMMAND__PRE_ORIGINATE\x10\x90N\x12\'\n\"CLOSE_GOAL_COMMAND__POST_ORIGINATE\x10\x91N\x12#\n\x1e\x43LOSE_GOAL_COMMAND__PRE_UPDATE\x10\x92N\x12$\n\x1f\x43LOSE_GOAL_COMMAND__POST_UPDATE\x10\x93N\x12#\n\x1e\x43LOSE_GOAL_COMMAND__PRE_COMMIT\x10\x94N\x12$\n\x1f\x43LOSE_GOAL_COMMAND__POST_COMMIT\x10\x95N\x12#\n\x1e\x43LOSE_GOAL_COMMAND__PRE_DELETE\x10\x96N\x12$\n\x1f\x43LOSE_GOAL_COMMAND__POST_DELETE\x10\x97N\x12+\n&CLOSE_GOAL_COMMAND__PRE_ENTER_IN_ERROR\x10\x98N\x12,\n\'CLOSE_GOAL_COMMAND__POST_ENTER_IN_ERROR\x10\x99N\x12+\n&CLOSE_GOAL_COMMAND__PRE_EXECUTE_ACTION\x10\x9aN\x12,\n\'CLOSE_GOAL_COMMAND__POST_EXECUTE_ACTION\x10\x9bN\x12\x30\n+CLOSE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE\x10\x9eN\x12*\n%CLOSE_GOAL_COMMAND__AVAILABLE_ACTIONS\x10\x9fN\x12$\n\x1f\x43LOSE_GOAL__GOAL_ID__PRE_SEARCH\x10\x9cN\x12%\n CLOSE_GOAL__GOAL_ID__POST_SEARCH\x10\x9dN\x12$\n\x1f\x44IAGNOSE_COMMAND__PRE_ORIGINATE\x10\xb0m\x12%\n DIAGNOSE_COMMAND__POST_ORIGINATE\x10\xb1m\x12!\n\x1c\x44IAGNOSE_COMMAND__PRE_UPDATE\x10\xb2m\x12\"\n\x1d\x44IAGNOSE_COMMAND__POST_UPDATE\x10\xb3m\x12!\n\x1c\x44IAGNOSE_COMMAND__PRE_COMMIT\x10\xb4m\x12\"\n\x1d\x44IAGNOSE_COMMAND__POST_COMMIT\x10\xb5m\x12!\n\x1c\x44IAGNOSE_COMMAND__PRE_DELETE\x10\xb6m\x12\"\n\x1d\x44IAGNOSE_COMMAND__POST_DELETE\x10\xb7m\x12)\n$DIAGNOSE_COMMAND__PRE_ENTER_IN_ERROR\x10\xb8m\x12*\n%DIAGNOSE_COMMAND__POST_ENTER_IN_ERROR\x10\xb9m\x12)\n$DIAGNOSE_COMMAND__PRE_EXECUTE_ACTION\x10\xbam\x12*\n%DIAGNOSE_COMMAND__POST_EXECUTE_ACTION\x10\xbbm\x12.\n)DIAGNOSE_COMMAND__POST_INSERTED_INTO_NOTE\x10\xbem\x12(\n#DIAGNOSE_COMMAND__AVAILABLE_ACTIONS\x10\xbfm\x12$\n\x1f\x44IAGNOSE__DIAGNOSE__POST_SEARCH\x10\xbcm\x12#\n\x1e\x44IAGNOSE__DIAGNOSE__PRE_SEARCH\x10\xbdm\x12\x30\n+EDUCATIONAL_MATERIAL_COMMAND__PRE_ORIGINATE\x10\x98u\x12\x31\n,EDUCATIONAL_MATERIAL_COMMAND__POST_ORIGINATE\x10\x99u\x12-\n(EDUCATIONAL_MATERIAL_COMMAND__PRE_UPDATE\x10\x9au\x12.\n)EDUCATIONAL_MATERIAL_COMMAND__POST_UPDATE\x10\x9bu\x12-\n(EDUCATIONAL_MATERIAL_COMMAND__PRE_COMMIT\x10\x9cu\x12.\n)EDUCATIONAL_MATERIAL_COMMAND__POST_COMMIT\x10\x9du\x12-\n(EDUCATIONAL_MATERIAL_COMMAND__PRE_DELETE\x10\x9eu\x12.\n)EDUCATIONAL_MATERIAL_COMMAND__POST_DELETE\x10\x9fu\x12\x35\n0EDUCATIONAL_MATERIAL_COMMAND__PRE_ENTER_IN_ERROR\x10\xa0u\x12\x36\n1EDUCATIONAL_MATERIAL_COMMAND__POST_ENTER_IN_ERROR\x10\xa1u\x12\x35\n0EDUCATIONAL_MATERIAL_COMMAND__PRE_EXECUTE_ACTION\x10\xa2u\x12\x36\n1EDUCATIONAL_MATERIAL_COMMAND__POST_EXECUTE_ACTION\x10\xa3u\x12:\n5EDUCATIONAL_MATERIAL_COMMAND__POST_INSERTED_INTO_NOTE\x10\xa8u\x12\x34\n/EDUCATIONAL_MATERIAL_COMMAND__AVAILABLE_ACTIONS\x10\xa9u\x12,\n\'EDUCATIONAL_MATERIAL__TITLE__PRE_SEARCH\x10\xa4u\x12-\n(EDUCATIONAL_MATERIAL__TITLE__POST_SEARCH\x10\xa5u\x12/\n*EDUCATIONAL_MATERIAL__LANGUAGE__PRE_SEARCH\x10\xa6u\x12\x30\n+EDUCATIONAL_MATERIAL__LANGUAGE__POST_SEARCH\x10\xa7u\x12*\n%FAMILY_HISTORY_COMMAND__PRE_ORIGINATE\x10\x80}\x12+\n&FAMILY_HISTORY_COMMAND__POST_ORIGINATE\x10\x81}\x12\'\n\"FAMILY_HISTORY_COMMAND__PRE_UPDATE\x10\x82}\x12(\n#FAMILY_HISTORY_COMMAND__POST_UPDATE\x10\x83}\x12\'\n\"FAMILY_HISTORY_COMMAND__PRE_COMMIT\x10\x84}\x12(\n#FAMILY_HISTORY_COMMAND__POST_COMMIT\x10\x85}\x12\'\n\"FAMILY_HISTORY_COMMAND__PRE_DELETE\x10\x86}\x12(\n#FAMILY_HISTORY_COMMAND__POST_DELETE\x10\x87}\x12/\n*FAMILY_HISTORY_COMMAND__PRE_ENTER_IN_ERROR\x10\x88}\x12\x30\n+FAMILY_HISTORY_COMMAND__POST_ENTER_IN_ERROR\x10\x89}\x12/\n*FAMILY_HISTORY_COMMAND__PRE_EXECUTE_ACTION\x10\x8a}\x12\x30\n+FAMILY_HISTORY_COMMAND__POST_EXECUTE_ACTION\x10\x8b}\x12\x34\n/FAMILY_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE\x10\x90}\x12.\n)FAMILY_HISTORY_COMMAND__AVAILABLE_ACTIONS\x10\x91}\x12/\n*FAMILY_HISTORY__FAMILY_HISTORY__PRE_SEARCH\x10\x8c}\x12\x30\n+FAMILY_HISTORY__FAMILY_HISTORY__POST_SEARCH\x10\x8d}\x12)\n$FAMILY_HISTORY__RELATIVE__PRE_SEARCH\x10\x8e}\x12*\n%FAMILY_HISTORY__RELATIVE__POST_SEARCH\x10\x8f}\x12&\n FOLLOW_UP_COMMAND__PRE_ORIGINATE\x10\xe8\x84\x01\x12\'\n!FOLLOW_UP_COMMAND__POST_ORIGINATE\x10\xe9\x84\x01\x12#\n\x1d\x46OLLOW_UP_COMMAND__PRE_UPDATE\x10\xea\x84\x01\x12$\n\x1e\x46OLLOW_UP_COMMAND__POST_UPDATE\x10\xeb\x84\x01\x12#\n\x1d\x46OLLOW_UP_COMMAND__PRE_COMMIT\x10\xec\x84\x01\x12$\n\x1e\x46OLLOW_UP_COMMAND__POST_COMMIT\x10\xed\x84\x01\x12#\n\x1d\x46OLLOW_UP_COMMAND__PRE_DELETE\x10\xee\x84\x01\x12$\n\x1e\x46OLLOW_UP_COMMAND__POST_DELETE\x10\xef\x84\x01\x12+\n%FOLLOW_UP_COMMAND__PRE_ENTER_IN_ERROR\x10\xf0\x84\x01\x12,\n&FOLLOW_UP_COMMAND__POST_ENTER_IN_ERROR\x10\xf1\x84\x01\x12+\n%FOLLOW_UP_COMMAND__PRE_EXECUTE_ACTION\x10\xf2\x84\x01\x12,\n&FOLLOW_UP_COMMAND__POST_EXECUTE_ACTION\x10\xf3\x84\x01\x12\x30\n*FOLLOW_UP_COMMAND__POST_INSERTED_INTO_NOTE\x10\xf8\x84\x01\x12*\n$FOLLOW_UP_COMMAND__AVAILABLE_ACTIONS\x10\xf9\x84\x01\x12#\n\x1d\x46OLLOW_UP__CODING__PRE_SEARCH\x10\xf4\x84\x01\x12$\n\x1e\x46OLLOW_UP__CODING__POST_SEARCH\x10\xf5\x84\x01\x12&\n FOLLOW_UP__NOTE_TYPE__PRE_SEARCH\x10\xf6\x84\x01\x12\'\n!FOLLOW_UP__NOTE_TYPE__POST_SEARCH\x10\xf7\x84\x01\x12!\n\x1bGOAL_COMMAND__PRE_ORIGINATE\x10\xd0\x8c\x01\x12\"\n\x1cGOAL_COMMAND__POST_ORIGINATE\x10\xd1\x8c\x01\x12\x1e\n\x18GOAL_COMMAND__PRE_UPDATE\x10\xd2\x8c\x01\x12\x1f\n\x19GOAL_COMMAND__POST_UPDATE\x10\xd3\x8c\x01\x12\x1e\n\x18GOAL_COMMAND__PRE_COMMIT\x10\xd4\x8c\x01\x12\x1f\n\x19GOAL_COMMAND__POST_COMMIT\x10\xd5\x8c\x01\x12\x1e\n\x18GOAL_COMMAND__PRE_DELETE\x10\xd6\x8c\x01\x12\x1f\n\x19GOAL_COMMAND__POST_DELETE\x10\xd7\x8c\x01\x12&\n GOAL_COMMAND__PRE_ENTER_IN_ERROR\x10\xd8\x8c\x01\x12\'\n!GOAL_COMMAND__POST_ENTER_IN_ERROR\x10\xd9\x8c\x01\x12&\n GOAL_COMMAND__PRE_EXECUTE_ACTION\x10\xda\x8c\x01\x12\'\n!GOAL_COMMAND__POST_EXECUTE_ACTION\x10\xdb\x8c\x01\x12+\n%GOAL_COMMAND__POST_INSERTED_INTO_NOTE\x10\xde\x8c\x01\x12%\n\x1fGOAL_COMMAND__AVAILABLE_ACTIONS\x10\xdf\x8c\x01\x12\x37\n1HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ORIGINATE\x10\xb8\x94\x01\x12\x38\n2HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ORIGINATE\x10\xb9\x94\x01\x12\x34\n.HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_UPDATE\x10\xba\x94\x01\x12\x35\n/HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_UPDATE\x10\xbb\x94\x01\x12\x34\n.HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_COMMIT\x10\xbc\x94\x01\x12\x35\n/HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_COMMIT\x10\xbd\x94\x01\x12\x34\n.HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_DELETE\x10\xbe\x94\x01\x12\x35\n/HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_DELETE\x10\xbf\x94\x01\x12<\n6HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ENTER_IN_ERROR\x10\xc0\x94\x01\x12=\n7HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ENTER_IN_ERROR\x10\xc1\x94\x01\x12<\n6HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_EXECUTE_ACTION\x10\xc2\x94\x01\x12=\n7HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_EXECUTE_ACTION\x10\xc3\x94\x01\x12\x41\n;HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_INSERTED_INTO_NOTE\x10\xc4\x94\x01\x12;\n5HISTORY_OF_PRESENT_ILLNESS_COMMAND__AVAILABLE_ACTIONS\x10\xc5\x94\x01\x12*\n$IMAGING_ORDER_COMMAND__PRE_ORIGINATE\x10\xa0\x9c\x01\x12+\n%IMAGING_ORDER_COMMAND__POST_ORIGINATE\x10\xa1\x9c\x01\x12\'\n!IMAGING_ORDER_COMMAND__PRE_UPDATE\x10\xa2\x9c\x01\x12(\n\"IMAGING_ORDER_COMMAND__POST_UPDATE\x10\xa3\x9c\x01\x12\'\n!IMAGING_ORDER_COMMAND__PRE_COMMIT\x10\xa4\x9c\x01\x12(\n\"IMAGING_ORDER_COMMAND__POST_COMMIT\x10\xa5\x9c\x01\x12\'\n!IMAGING_ORDER_COMMAND__PRE_DELETE\x10\xa6\x9c\x01\x12(\n\"IMAGING_ORDER_COMMAND__POST_DELETE\x10\xa7\x9c\x01\x12/\n)IMAGING_ORDER_COMMAND__PRE_ENTER_IN_ERROR\x10\xa8\x9c\x01\x12\x30\n*IMAGING_ORDER_COMMAND__POST_ENTER_IN_ERROR\x10\xa9\x9c\x01\x12/\n)IMAGING_ORDER_COMMAND__PRE_EXECUTE_ACTION\x10\xaa\x9c\x01\x12\x30\n*IMAGING_ORDER_COMMAND__POST_EXECUTE_ACTION\x10\xab\x9c\x01\x12\x34\n.IMAGING_ORDER_COMMAND__POST_INSERTED_INTO_NOTE\x10\xb4\x9c\x01\x12.\n(IMAGING_ORDER_COMMAND__AVAILABLE_ACTIONS\x10\xb5\x9c\x01\x12&\n IMAGING_ORDER__IMAGE__PRE_SEARCH\x10\xac\x9c\x01\x12\'\n!IMAGING_ORDER__IMAGE__POST_SEARCH\x10\xad\x9c\x01\x12,\n&IMAGING_ORDER__INDICATIONS__PRE_SEARCH\x10\xae\x9c\x01\x12-\n\'IMAGING_ORDER__INDICATIONS__POST_SEARCH\x10\xaf\x9c\x01\x12/\n)IMAGING_ORDER__IMAGING_CENTER__PRE_SEARCH\x10\xb0\x9c\x01\x12\x30\n*IMAGING_ORDER__IMAGING_CENTER__POST_SEARCH\x10\xb1\x9c\x01\x12\x32\n,IMAGING_ORDER__ORDERING_PROVIDER__PRE_SEARCH\x10\xb2\x9c\x01\x12\x33\n-IMAGING_ORDER__ORDERING_PROVIDER__POST_SEARCH\x10\xb3\x9c\x01\x12\x33\n-IMMUNIZATION_STATEMENT_COMMAND__PRE_ORIGINATE\x10\xf0\xab\x01\x12\x34\n.IMMUNIZATION_STATEMENT_COMMAND__POST_ORIGINATE\x10\xf1\xab\x01\x12\x30\n*IMMUNIZATION_STATEMENT_COMMAND__PRE_UPDATE\x10\xf2\xab\x01\x12\x31\n+IMMUNIZATION_STATEMENT_COMMAND__POST_UPDATE\x10\xf3\xab\x01\x12\x30\n*IMMUNIZATION_STATEMENT_COMMAND__PRE_COMMIT\x10\xf4\xab\x01\x12\x31\n+IMMUNIZATION_STATEMENT_COMMAND__POST_COMMIT\x10\xf5\xab\x01\x12\x30\n*IMMUNIZATION_STATEMENT_COMMAND__PRE_DELETE\x10\xf6\xab\x01\x12\x31\n+IMMUNIZATION_STATEMENT_COMMAND__POST_DELETE\x10\xf7\xab\x01\x12\x38\n2IMMUNIZATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR\x10\xf8\xab\x01\x12\x39\n3IMMUNIZATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR\x10\xf9\xab\x01\x12\x38\n2IMMUNIZATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION\x10\xfa\xab\x01\x12\x39\n3IMMUNIZATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION\x10\xfb\xab\x01\x12=\n7IMMUNIZATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE\x10\xfe\xab\x01\x12\x37\n1IMMUNIZATION_STATEMENT_COMMAND__AVAILABLE_ACTIONS\x10\xff\xab\x01\x12\x33\n-IMMUNIZATION_STATEMENT__STATEMENT__PRE_SEARCH\x10\xfc\xab\x01\x12\x34\n.IMMUNIZATION_STATEMENT__STATEMENT__POST_SEARCH\x10\xfd\xab\x01\x12%\n\x1fIMMUNIZE_COMMAND__PRE_ORIGINATE\x10\xd8\xb3\x01\x12&\n IMMUNIZE_COMMAND__POST_ORIGINATE\x10\xd9\xb3\x01\x12\"\n\x1cIMMUNIZE_COMMAND__PRE_UPDATE\x10\xda\xb3\x01\x12#\n\x1dIMMUNIZE_COMMAND__POST_UPDATE\x10\xdb\xb3\x01\x12\"\n\x1cIMMUNIZE_COMMAND__PRE_COMMIT\x10\xdc\xb3\x01\x12#\n\x1dIMMUNIZE_COMMAND__POST_COMMIT\x10\xdd\xb3\x01\x12\"\n\x1cIMMUNIZE_COMMAND__PRE_DELETE\x10\xde\xb3\x01\x12#\n\x1dIMMUNIZE_COMMAND__POST_DELETE\x10\xdf\xb3\x01\x12*\n$IMMUNIZE_COMMAND__PRE_ENTER_IN_ERROR\x10\xe0\xb3\x01\x12+\n%IMMUNIZE_COMMAND__POST_ENTER_IN_ERROR\x10\xe1\xb3\x01\x12*\n$IMMUNIZE_COMMAND__PRE_EXECUTE_ACTION\x10\xe2\xb3\x01\x12+\n%IMMUNIZE_COMMAND__POST_EXECUTE_ACTION\x10\xe3\xb3\x01\x12/\n)IMMUNIZE_COMMAND__POST_INSERTED_INTO_NOTE\x10\xea\xb3\x01\x12)\n#IMMUNIZE_COMMAND__AVAILABLE_ACTIONS\x10\xeb\xb3\x01\x12\"\n\x1cIMMUNIZE__CODING__PRE_SEARCH\x10\xe4\xb3\x01\x12#\n\x1dIMMUNIZE__CODING__POST_SEARCH\x10\xe5\xb3\x01\x12&\n IMMUNIZE__LOT_NUMBER__PRE_SEARCH\x10\xe6\xb3\x01\x12\'\n!IMMUNIZE__LOT_NUMBER__POST_SEARCH\x10\xe7\xb3\x01\x12$\n\x1eIMMUNIZE__GIVEN_BY__PRE_SEARCH\x10\xe8\xb3\x01\x12%\n\x1fIMMUNIZE__GIVEN_BY__POST_SEARCH\x10\xe9\xb3\x01\x12%\n\x1fINSTRUCT_COMMAND__PRE_ORIGINATE\x10\xc0\xbb\x01\x12&\n INSTRUCT_COMMAND__POST_ORIGINATE\x10\xc1\xbb\x01\x12\"\n\x1cINSTRUCT_COMMAND__PRE_UPDATE\x10\xc2\xbb\x01\x12#\n\x1dINSTRUCT_COMMAND__POST_UPDATE\x10\xc3\xbb\x01\x12\"\n\x1cINSTRUCT_COMMAND__PRE_COMMIT\x10\xc4\xbb\x01\x12#\n\x1dINSTRUCT_COMMAND__POST_COMMIT\x10\xc5\xbb\x01\x12\"\n\x1cINSTRUCT_COMMAND__PRE_DELETE\x10\xc6\xbb\x01\x12#\n\x1dINSTRUCT_COMMAND__POST_DELETE\x10\xc7\xbb\x01\x12*\n$INSTRUCT_COMMAND__PRE_ENTER_IN_ERROR\x10\xc8\xbb\x01\x12+\n%INSTRUCT_COMMAND__POST_ENTER_IN_ERROR\x10\xc9\xbb\x01\x12*\n$INSTRUCT_COMMAND__PRE_EXECUTE_ACTION\x10\xca\xbb\x01\x12+\n%INSTRUCT_COMMAND__POST_EXECUTE_ACTION\x10\xcb\xbb\x01\x12/\n)INSTRUCT_COMMAND__POST_INSERTED_INTO_NOTE\x10\xce\xbb\x01\x12)\n#INSTRUCT_COMMAND__AVAILABLE_ACTIONS\x10\xcf\xbb\x01\x12$\n\x1eINSTRUCT__INSTRUCT__PRE_SEARCH\x10\xcc\xbb\x01\x12%\n\x1fINSTRUCT__INSTRUCT__POST_SEARCH\x10\xcd\xbb\x01\x12&\n LAB_ORDER_COMMAND__PRE_ORIGINATE\x10\xa8\xc3\x01\x12\'\n!LAB_ORDER_COMMAND__POST_ORIGINATE\x10\xa9\xc3\x01\x12#\n\x1dLAB_ORDER_COMMAND__PRE_UPDATE\x10\xaa\xc3\x01\x12$\n\x1eLAB_ORDER_COMMAND__POST_UPDATE\x10\xab\xc3\x01\x12#\n\x1dLAB_ORDER_COMMAND__PRE_COMMIT\x10\xac\xc3\x01\x12$\n\x1eLAB_ORDER_COMMAND__POST_COMMIT\x10\xad\xc3\x01\x12#\n\x1dLAB_ORDER_COMMAND__PRE_DELETE\x10\xae\xc3\x01\x12$\n\x1eLAB_ORDER_COMMAND__POST_DELETE\x10\xaf\xc3\x01\x12+\n%LAB_ORDER_COMMAND__PRE_ENTER_IN_ERROR\x10\xb0\xc3\x01\x12,\n&LAB_ORDER_COMMAND__POST_ENTER_IN_ERROR\x10\xb1\xc3\x01\x12+\n%LAB_ORDER_COMMAND__PRE_EXECUTE_ACTION\x10\xb2\xc3\x01\x12,\n&LAB_ORDER_COMMAND__POST_EXECUTE_ACTION\x10\xb3\xc3\x01\x12\x30\n*LAB_ORDER_COMMAND__POST_INSERTED_INTO_NOTE\x10\xbc\xc3\x01\x12*\n$LAB_ORDER_COMMAND__AVAILABLE_ACTIONS\x10\xbd\xc3\x01\x12(\n\"LAB_ORDER__LAB_PARTNER__PRE_SEARCH\x10\xb4\xc3\x01\x12)\n#LAB_ORDER__LAB_PARTNER__POST_SEARCH\x10\xb5\xc3\x01\x12\"\n\x1cLAB_ORDER__TESTS__PRE_SEARCH\x10\xb6\xc3\x01\x12#\n\x1dLAB_ORDER__TESTS__POST_SEARCH\x10\xb7\xc3\x01\x12.\n(LAB_ORDER__ORDERING_PROVIDER__PRE_SEARCH\x10\xb8\xc3\x01\x12/\n)LAB_ORDER__ORDERING_PROVIDER__POST_SEARCH\x10\xb9\xc3\x01\x12&\n LAB_ORDER__DIAGNOSIS__PRE_SEARCH\x10\xba\xc3\x01\x12\'\n!LAB_ORDER__DIAGNOSIS__POST_SEARCH\x10\xbb\xc3\x01\x12,\n&MEDICAL_HISTORY_COMMAND__PRE_ORIGINATE\x10\xf8\xd2\x01\x12-\n\'MEDICAL_HISTORY_COMMAND__POST_ORIGINATE\x10\xf9\xd2\x01\x12)\n#MEDICAL_HISTORY_COMMAND__PRE_UPDATE\x10\xfa\xd2\x01\x12*\n$MEDICAL_HISTORY_COMMAND__POST_UPDATE\x10\xfb\xd2\x01\x12)\n#MEDICAL_HISTORY_COMMAND__PRE_COMMIT\x10\xfc\xd2\x01\x12*\n$MEDICAL_HISTORY_COMMAND__POST_COMMIT\x10\xfd\xd2\x01\x12)\n#MEDICAL_HISTORY_COMMAND__PRE_DELETE\x10\xfe\xd2\x01\x12*\n$MEDICAL_HISTORY_COMMAND__POST_DELETE\x10\xff\xd2\x01\x12\x31\n+MEDICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR\x10\x80\xd3\x01\x12\x32\n,MEDICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR\x10\x81\xd3\x01\x12\x31\n+MEDICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION\x10\x82\xd3\x01\x12\x32\n,MEDICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION\x10\x83\xd3\x01\x12\x36\n0MEDICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE\x10\x8a\xd3\x01\x12\x30\n*MEDICAL_HISTORY_COMMAND__AVAILABLE_ACTIONS\x10\x8b\xd3\x01\x12\x37\n1MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__PRE_SEARCH\x10\x84\xd3\x01\x12\x38\n2MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__POST_SEARCH\x10\x85\xd3\x01\x12\x39\n3MEDICAL_HISTORY__APPROXIMATE_START_DATE__PRE_SEARCH\x10\x86\xd3\x01\x12:\n4MEDICAL_HISTORY__APPROXIMATE_START_DATE__POST_SEARCH\x10\x87\xd3\x01\x12\x37\n1MEDICAL_HISTORY__APPROXIMATE_END_DATE__PRE_SEARCH\x10\x88\xd3\x01\x12\x38\n2MEDICAL_HISTORY__APPROXIMATE_END_DATE__POST_SEARCH\x10\x89\xd3\x01\x12\x31\n+MEDICATION_STATEMENT_COMMAND__PRE_ORIGINATE\x10\xe0\xda\x01\x12\x32\n,MEDICATION_STATEMENT_COMMAND__POST_ORIGINATE\x10\xe1\xda\x01\x12.\n(MEDICATION_STATEMENT_COMMAND__PRE_UPDATE\x10\xe2\xda\x01\x12/\n)MEDICATION_STATEMENT_COMMAND__POST_UPDATE\x10\xe3\xda\x01\x12.\n(MEDICATION_STATEMENT_COMMAND__PRE_COMMIT\x10\xe4\xda\x01\x12/\n)MEDICATION_STATEMENT_COMMAND__POST_COMMIT\x10\xe5\xda\x01\x12.\n(MEDICATION_STATEMENT_COMMAND__PRE_DELETE\x10\xe6\xda\x01\x12/\n)MEDICATION_STATEMENT_COMMAND__POST_DELETE\x10\xe7\xda\x01\x12\x36\n0MEDICATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR\x10\xe8\xda\x01\x12\x37\n1MEDICATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR\x10\xe9\xda\x01\x12\x36\n0MEDICATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION\x10\xea\xda\x01\x12\x37\n1MEDICATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION\x10\xeb\xda\x01\x12;\n5MEDICATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE\x10\xec\xda\x01\x12\x35\n/MEDICATION_STATEMENT_COMMAND__AVAILABLE_ACTIONS\x10\xed\xda\x01\x12$\n\x1ePERFORM_COMMAND__PRE_ORIGINATE\x10\xc8\xe2\x01\x12%\n\x1fPERFORM_COMMAND__POST_ORIGINATE\x10\xc9\xe2\x01\x12!\n\x1bPERFORM_COMMAND__PRE_UPDATE\x10\xca\xe2\x01\x12\"\n\x1cPERFORM_COMMAND__POST_UPDATE\x10\xcb\xe2\x01\x12!\n\x1bPERFORM_COMMAND__PRE_COMMIT\x10\xcc\xe2\x01\x12\"\n\x1cPERFORM_COMMAND__POST_COMMIT\x10\xcd\xe2\x01\x12!\n\x1bPERFORM_COMMAND__PRE_DELETE\x10\xce\xe2\x01\x12\"\n\x1cPERFORM_COMMAND__POST_DELETE\x10\xcf\xe2\x01\x12)\n#PERFORM_COMMAND__PRE_ENTER_IN_ERROR\x10\xd0\xe2\x01\x12*\n$PERFORM_COMMAND__POST_ENTER_IN_ERROR\x10\xd1\xe2\x01\x12)\n#PERFORM_COMMAND__PRE_EXECUTE_ACTION\x10\xd2\xe2\x01\x12*\n$PERFORM_COMMAND__POST_EXECUTE_ACTION\x10\xd3\xe2\x01\x12.\n(PERFORM_COMMAND__POST_INSERTED_INTO_NOTE\x10\xd6\xe2\x01\x12(\n\"PERFORM_COMMAND__AVAILABLE_ACTIONS\x10\xd7\xe2\x01\x12\"\n\x1cPERFORM__PERFORM__PRE_SEARCH\x10\xd4\xe2\x01\x12#\n\x1dPERFORM__PERFORM__POST_SEARCH\x10\xd5\xe2\x01\x12*\n$PHYSICAL_EXAM_COMMAND__PRE_ORIGINATE\x10\xb0\xea\x01\x12+\n%PHYSICAL_EXAM_COMMAND__POST_ORIGINATE\x10\xb1\xea\x01\x12\'\n!PHYSICAL_EXAM_COMMAND__PRE_UPDATE\x10\xb2\xea\x01\x12(\n\"PHYSICAL_EXAM_COMMAND__POST_UPDATE\x10\xb3\xea\x01\x12\'\n!PHYSICAL_EXAM_COMMAND__PRE_COMMIT\x10\xb4\xea\x01\x12(\n\"PHYSICAL_EXAM_COMMAND__POST_COMMIT\x10\xb5\xea\x01\x12\'\n!PHYSICAL_EXAM_COMMAND__PRE_DELETE\x10\xb6\xea\x01\x12(\n\"PHYSICAL_EXAM_COMMAND__POST_DELETE\x10\xb7\xea\x01\x12/\n)PHYSICAL_EXAM_COMMAND__PRE_ENTER_IN_ERROR\x10\xb8\xea\x01\x12\x30\n*PHYSICAL_EXAM_COMMAND__POST_ENTER_IN_ERROR\x10\xb9\xea\x01\x12/\n)PHYSICAL_EXAM_COMMAND__PRE_EXECUTE_ACTION\x10\xba\xea\x01\x12\x30\n*PHYSICAL_EXAM_COMMAND__POST_EXECUTE_ACTION\x10\xbb\xea\x01\x12\x34\n.PHYSICAL_EXAM_COMMAND__POST_INSERTED_INTO_NOTE\x10\xbe\xea\x01\x12.\n(PHYSICAL_EXAM_COMMAND__AVAILABLE_ACTIONS\x10\xbf\xea\x01\x12.\n(PHYSICAL_EXAM__QUESTIONNAIRE__PRE_SEARCH\x10\xbc\xea\x01\x12/\n)PHYSICAL_EXAM__QUESTIONNAIRE__POST_SEARCH\x10\xbd\xea\x01\x12!\n\x1bPLAN_COMMAND__PRE_ORIGINATE\x10\x98\xf2\x01\x12\"\n\x1cPLAN_COMMAND__POST_ORIGINATE\x10\x99\xf2\x01\x12\x1e\n\x18PLAN_COMMAND__PRE_UPDATE\x10\x9a\xf2\x01\x12\x1f\n\x19PLAN_COMMAND__POST_UPDATE\x10\x9b\xf2\x01\x12\x1e\n\x18PLAN_COMMAND__PRE_COMMIT\x10\x9c\xf2\x01\x12\x1f\n\x19PLAN_COMMAND__POST_COMMIT\x10\x9d\xf2\x01\x12\x1e\n\x18PLAN_COMMAND__PRE_DELETE\x10\x9e\xf2\x01\x12\x1f\n\x19PLAN_COMMAND__POST_DELETE\x10\x9f\xf2\x01\x12&\n PLAN_COMMAND__PRE_ENTER_IN_ERROR\x10\xa0\xf2\x01\x12\'\n!PLAN_COMMAND__POST_ENTER_IN_ERROR\x10\xa1\xf2\x01\x12&\n PLAN_COMMAND__PRE_EXECUTE_ACTION\x10\xa2\xf2\x01\x12\'\n!PLAN_COMMAND__POST_EXECUTE_ACTION\x10\xa3\xf2\x01\x12+\n%PLAN_COMMAND__POST_INSERTED_INTO_NOTE\x10\xa4\xf2\x01\x12%\n\x1fPLAN_COMMAND__AVAILABLE_ACTIONS\x10\xa5\xf2\x01\x12&\n PRESCRIBE_COMMAND__PRE_ORIGINATE\x10\xe8\x81\x02\x12\'\n!PRESCRIBE_COMMAND__POST_ORIGINATE\x10\xe9\x81\x02\x12#\n\x1dPRESCRIBE_COMMAND__PRE_UPDATE\x10\xea\x81\x02\x12$\n\x1ePRESCRIBE_COMMAND__POST_UPDATE\x10\xeb\x81\x02\x12#\n\x1dPRESCRIBE_COMMAND__PRE_COMMIT\x10\xec\x81\x02\x12$\n\x1ePRESCRIBE_COMMAND__POST_COMMIT\x10\xed\x81\x02\x12#\n\x1dPRESCRIBE_COMMAND__PRE_DELETE\x10\xee\x81\x02\x12$\n\x1ePRESCRIBE_COMMAND__POST_DELETE\x10\xef\x81\x02\x12+\n%PRESCRIBE_COMMAND__PRE_ENTER_IN_ERROR\x10\xf0\x81\x02\x12,\n&PRESCRIBE_COMMAND__POST_ENTER_IN_ERROR\x10\xf1\x81\x02\x12+\n%PRESCRIBE_COMMAND__PRE_EXECUTE_ACTION\x10\xf2\x81\x02\x12,\n&PRESCRIBE_COMMAND__POST_EXECUTE_ACTION\x10\xf3\x81\x02\x12\x30\n*PRESCRIBE_COMMAND__POST_INSERTED_INTO_NOTE\x10\xfa\x81\x02\x12*\n$PRESCRIBE_COMMAND__AVAILABLE_ACTIONS\x10\xfd\x81\x02\x12\'\n!PRESCRIBE__PRESCRIBE__POST_SEARCH\x10\xf4\x81\x02\x12&\n PRESCRIBE__PRESCRIBE__PRE_SEARCH\x10\xf5\x81\x02\x12(\n\"PRESCRIBE__INDICATIONS__PRE_SEARCH\x10\xf6\x81\x02\x12)\n#PRESCRIBE__INDICATIONS__POST_SEARCH\x10\xf7\x81\x02\x12%\n\x1fPRESCRIBE__PHARMACY__PRE_SEARCH\x10\xf8\x81\x02\x12&\n PRESCRIBE__PHARMACY__POST_SEARCH\x10\xf9\x81\x02\x12\x32\n,PRESCRIBE__SUPERVISING_PROVIDER__POST_SEARCH\x10\xfb\x81\x02\x12\x31\n+PRESCRIBE__SUPERVISING_PROVIDER__PRE_SEARCH\x10\xfc\x81\x02\x12\'\n!PRESCRIBE__PRESCRIBER__PRE_SEARCH\x10\xff\x81\x02\x12(\n\"PRESCRIBE__PRESCRIBER__POST_SEARCH\x10\x80\x82\x02\x12*\n$QUESTIONNAIRE_COMMAND__PRE_ORIGINATE\x10\xd0\x89\x02\x12+\n%QUESTIONNAIRE_COMMAND__POST_ORIGINATE\x10\xd1\x89\x02\x12\'\n!QUESTIONNAIRE_COMMAND__PRE_UPDATE\x10\xd2\x89\x02\x12(\n\"QUESTIONNAIRE_COMMAND__POST_UPDATE\x10\xd3\x89\x02\x12\'\n!QUESTIONNAIRE_COMMAND__PRE_COMMIT\x10\xd4\x89\x02\x12(\n\"QUESTIONNAIRE_COMMAND__POST_COMMIT\x10\xd5\x89\x02\x12\'\n!QUESTIONNAIRE_COMMAND__PRE_DELETE\x10\xd6\x89\x02\x12(\n\"QUESTIONNAIRE_COMMAND__POST_DELETE\x10\xd7\x89\x02\x12/\n)QUESTIONNAIRE_COMMAND__PRE_ENTER_IN_ERROR\x10\xd8\x89\x02\x12\x30\n*QUESTIONNAIRE_COMMAND__POST_ENTER_IN_ERROR\x10\xd9\x89\x02\x12/\n)QUESTIONNAIRE_COMMAND__PRE_EXECUTE_ACTION\x10\xda\x89\x02\x12\x30\n*QUESTIONNAIRE_COMMAND__POST_EXECUTE_ACTION\x10\xdb\x89\x02\x12\x34\n.QUESTIONNAIRE_COMMAND__POST_INSERTED_INTO_NOTE\x10\xde\x89\x02\x12.\n(QUESTIONNAIRE_COMMAND__AVAILABLE_ACTIONS\x10\xdf\x89\x02\x12/\n)QUESTIONNAIRE__QUESTIONNAIRE__POST_SEARCH\x10\xdc\x89\x02\x12.\n(QUESTIONNAIRE__QUESTIONNAIRE__PRE_SEARCH\x10\xdd\x89\x02\x12-\n\'REASON_FOR_VISIT_COMMAND__PRE_ORIGINATE\x10\xb8\x91\x02\x12.\n(REASON_FOR_VISIT_COMMAND__POST_ORIGINATE\x10\xb9\x91\x02\x12*\n$REASON_FOR_VISIT_COMMAND__PRE_UPDATE\x10\xba\x91\x02\x12+\n%REASON_FOR_VISIT_COMMAND__POST_UPDATE\x10\xbb\x91\x02\x12*\n$REASON_FOR_VISIT_COMMAND__PRE_COMMIT\x10\xbc\x91\x02\x12+\n%REASON_FOR_VISIT_COMMAND__POST_COMMIT\x10\xbd\x91\x02\x12*\n$REASON_FOR_VISIT_COMMAND__PRE_DELETE\x10\xbe\x91\x02\x12+\n%REASON_FOR_VISIT_COMMAND__POST_DELETE\x10\xbf\x91\x02\x12\x32\n,REASON_FOR_VISIT_COMMAND__PRE_ENTER_IN_ERROR\x10\xc0\x91\x02\x12\x33\n-REASON_FOR_VISIT_COMMAND__POST_ENTER_IN_ERROR\x10\xc1\x91\x02\x12\x32\n,REASON_FOR_VISIT_COMMAND__PRE_EXECUTE_ACTION\x10\xc2\x91\x02\x12\x33\n-REASON_FOR_VISIT_COMMAND__POST_EXECUTE_ACTION\x10\xc3\x91\x02\x12\x37\n1REASON_FOR_VISIT_COMMAND__POST_INSERTED_INTO_NOTE\x10\xc6\x91\x02\x12\x31\n+REASON_FOR_VISIT_COMMAND__AVAILABLE_ACTIONS\x10\xc7\x91\x02\x12+\n%REASON_FOR_VISIT__CODING__POST_SEARCH\x10\xc4\x91\x02\x12*\n$REASON_FOR_VISIT__CODING__PRE_SEARCH\x10\xc5\x91\x02\x12\"\n\x1cREFER_COMMAND__PRE_ORIGINATE\x10\xa0\x99\x02\x12#\n\x1dREFER_COMMAND__POST_ORIGINATE\x10\xa1\x99\x02\x12\x1f\n\x19REFER_COMMAND__PRE_UPDATE\x10\xa2\x99\x02\x12 \n\x1aREFER_COMMAND__POST_UPDATE\x10\xa3\x99\x02\x12\x1f\n\x19REFER_COMMAND__PRE_COMMIT\x10\xa4\x99\x02\x12 \n\x1aREFER_COMMAND__POST_COMMIT\x10\xa5\x99\x02\x12\x1f\n\x19REFER_COMMAND__PRE_DELETE\x10\xa6\x99\x02\x12 \n\x1aREFER_COMMAND__POST_DELETE\x10\xa7\x99\x02\x12\'\n!REFER_COMMAND__PRE_ENTER_IN_ERROR\x10\xa8\x99\x02\x12(\n\"REFER_COMMAND__POST_ENTER_IN_ERROR\x10\xa9\x99\x02\x12\'\n!REFER_COMMAND__PRE_EXECUTE_ACTION\x10\xaa\x99\x02\x12(\n\"REFER_COMMAND__POST_EXECUTE_ACTION\x10\xab\x99\x02\x12,\n&REFER_COMMAND__POST_INSERTED_INTO_NOTE\x10\xb4\x99\x02\x12&\n REFER_COMMAND__AVAILABLE_ACTIONS\x10\xb5\x99\x02\x12\"\n\x1cREFER__REFER_TO__POST_SEARCH\x10\xac\x99\x02\x12!\n\x1bREFER__REFER_TO__PRE_SEARCH\x10\xad\x99\x02\x12%\n\x1fREFER__INDICATIONS__POST_SEARCH\x10\xae\x99\x02\x12$\n\x1eREFER__INDICATIONS__PRE_SEARCH\x10\xaf\x99\x02\x12.\n(REFER__DOCUMENTS_TO_INCLUDE__POST_SEARCH\x10\xb0\x99\x02\x12-\n\'REFER__DOCUMENTS_TO_INCLUDE__PRE_SEARCH\x10\xb1\x99\x02\x12&\n REFER__LINKED_ITEMS__POST_SEARCH\x10\xb2\x99\x02\x12-\n\'REFER__LINKED_ITEMS_INCLUDE__PRE_SEARCH\x10\xb3\x99\x02\x12#\n\x1dREFILL_COMMAND__PRE_ORIGINATE\x10\xd8\xb0\x02\x12$\n\x1eREFILL_COMMAND__POST_ORIGINATE\x10\xd9\xb0\x02\x12 \n\x1aREFILL_COMMAND__PRE_UPDATE\x10\xda\xb0\x02\x12!\n\x1bREFILL_COMMAND__POST_UPDATE\x10\xdb\xb0\x02\x12 \n\x1aREFILL_COMMAND__PRE_COMMIT\x10\xdc\xb0\x02\x12!\n\x1bREFILL_COMMAND__POST_COMMIT\x10\xdd\xb0\x02\x12 \n\x1aREFILL_COMMAND__PRE_DELETE\x10\xde\xb0\x02\x12!\n\x1bREFILL_COMMAND__POST_DELETE\x10\xdf\xb0\x02\x12(\n\"REFILL_COMMAND__PRE_ENTER_IN_ERROR\x10\xe0\xb0\x02\x12)\n#REFILL_COMMAND__POST_ENTER_IN_ERROR\x10\xe1\xb0\x02\x12(\n\"REFILL_COMMAND__PRE_EXECUTE_ACTION\x10\xe2\xb0\x02\x12)\n#REFILL_COMMAND__POST_EXECUTE_ACTION\x10\xe3\xb0\x02\x12-\n\'REFILL_COMMAND__POST_INSERTED_INTO_NOTE\x10\xea\xb0\x02\x12\'\n!REFILL_COMMAND__AVAILABLE_ACTIONS\x10\xed\xb0\x02\x12#\n\x1dREFILL__PRESCRIBE__PRE_SEARCH\x10\xe4\xb0\x02\x12$\n\x1eREFILL__PRESCRIBE__POST_SEARCH\x10\xe5\xb0\x02\x12%\n\x1fREFILL__INDICATIONS__PRE_SEARCH\x10\xe6\xb0\x02\x12&\n REFILL__INDICATIONS__POST_SEARCH\x10\xe7\xb0\x02\x12\"\n\x1cREFILL__PHARMACY__PRE_SEARCH\x10\xe8\xb0\x02\x12#\n\x1dREFILL__PHARMACY__POST_SEARCH\x10\xe9\xb0\x02\x12.\n(REFILL__SUPERVISING_PROVIDER__PRE_SEARCH\x10\xeb\xb0\x02\x12/\n)REFILL__SUPERVISING_PROVIDER__POST_SEARCH\x10\xec\xb0\x02\x12$\n\x1eREFILL__PRESCRIBER__PRE_SEARCH\x10\xef\xb0\x02\x12%\n\x1fREFILL__PRESCRIBER__POST_SEARCH\x10\xf0\xb0\x02\x12+\n%REMOVE_ALLERGY_COMMAND__PRE_ORIGINATE\x10\xc0\xb8\x02\x12,\n&REMOVE_ALLERGY_COMMAND__POST_ORIGINATE\x10\xc1\xb8\x02\x12(\n\"REMOVE_ALLERGY_COMMAND__PRE_UPDATE\x10\xc2\xb8\x02\x12)\n#REMOVE_ALLERGY_COMMAND__POST_UPDATE\x10\xc3\xb8\x02\x12(\n\"REMOVE_ALLERGY_COMMAND__PRE_COMMIT\x10\xc4\xb8\x02\x12)\n#REMOVE_ALLERGY_COMMAND__POST_COMMIT\x10\xc5\xb8\x02\x12(\n\"REMOVE_ALLERGY_COMMAND__PRE_DELETE\x10\xc6\xb8\x02\x12)\n#REMOVE_ALLERGY_COMMAND__POST_DELETE\x10\xc7\xb8\x02\x12\x30\n*REMOVE_ALLERGY_COMMAND__PRE_ENTER_IN_ERROR\x10\xc8\xb8\x02\x12\x31\n+REMOVE_ALLERGY_COMMAND__POST_ENTER_IN_ERROR\x10\xc9\xb8\x02\x12\x30\n*REMOVE_ALLERGY_COMMAND__PRE_EXECUTE_ACTION\x10\xca\xb8\x02\x12\x31\n+REMOVE_ALLERGY_COMMAND__POST_EXECUTE_ACTION\x10\xcb\xb8\x02\x12\x35\n/REMOVE_ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE\x10\xce\xb8\x02\x12/\n)REMOVE_ALLERGY_COMMAND__AVAILABLE_ACTIONS\x10\xcf\xb8\x02\x12)\n#REMOVE_ALLERGY__ALLERGY__PRE_SEARCH\x10\xcc\xb8\x02\x12*\n$REMOVE_ALLERGY__ALLERGY__POST_SEARCH\x10\xcd\xb8\x02\x12.\n(RESOLVE_CONDITION_COMMAND__PRE_ORIGINATE\x10\xa8\xc0\x02\x12/\n)RESOLVE_CONDITION_COMMAND__POST_ORIGINATE\x10\xa9\xc0\x02\x12+\n%RESOLVE_CONDITION_COMMAND__PRE_UPDATE\x10\xaa\xc0\x02\x12,\n&RESOLVE_CONDITION_COMMAND__POST_UPDATE\x10\xab\xc0\x02\x12+\n%RESOLVE_CONDITION_COMMAND__PRE_COMMIT\x10\xac\xc0\x02\x12,\n&RESOLVE_CONDITION_COMMAND__POST_COMMIT\x10\xad\xc0\x02\x12+\n%RESOLVE_CONDITION_COMMAND__PRE_DELETE\x10\xae\xc0\x02\x12,\n&RESOLVE_CONDITION_COMMAND__POST_DELETE\x10\xaf\xc0\x02\x12\x33\n-RESOLVE_CONDITION_COMMAND__PRE_ENTER_IN_ERROR\x10\xb0\xc0\x02\x12\x34\n.RESOLVE_CONDITION_COMMAND__POST_ENTER_IN_ERROR\x10\xb1\xc0\x02\x12\x33\n-RESOLVE_CONDITION_COMMAND__PRE_EXECUTE_ACTION\x10\xb2\xc0\x02\x12\x34\n.RESOLVE_CONDITION_COMMAND__POST_EXECUTE_ACTION\x10\xb3\xc0\x02\x12\x38\n2RESOLVE_CONDITION_COMMAND__POST_INSERTED_INTO_NOTE\x10\xb6\xc0\x02\x12\x32\n,RESOLVE_CONDITION_COMMAND__AVAILABLE_ACTIONS\x10\xb7\xc0\x02\x12.\n(RESOLVE_CONDITION__CONDITION__PRE_SEARCH\x10\xb4\xc0\x02\x12/\n)RESOLVE_CONDITION__CONDITION__POST_SEARCH\x10\xb5\xc0\x02\x12 \n\x1aROS_COMMAND__PRE_ORIGINATE\x10\x90\xc8\x02\x12!\n\x1bROS_COMMAND__POST_ORIGINATE\x10\x91\xc8\x02\x12\x1d\n\x17ROS_COMMAND__PRE_UPDATE\x10\x92\xc8\x02\x12\x1e\n\x18ROS_COMMAND__POST_UPDATE\x10\x93\xc8\x02\x12\x1d\n\x17ROS_COMMAND__PRE_COMMIT\x10\x94\xc8\x02\x12\x1e\n\x18ROS_COMMAND__POST_COMMIT\x10\x95\xc8\x02\x12\x1d\n\x17ROS_COMMAND__PRE_DELETE\x10\x96\xc8\x02\x12\x1e\n\x18ROS_COMMAND__POST_DELETE\x10\x97\xc8\x02\x12%\n\x1fROS_COMMAND__PRE_ENTER_IN_ERROR\x10\x98\xc8\x02\x12&\n ROS_COMMAND__POST_ENTER_IN_ERROR\x10\x99\xc8\x02\x12%\n\x1fROS_COMMAND__PRE_EXECUTE_ACTION\x10\x9a\xc8\x02\x12&\n ROS_COMMAND__POST_EXECUTE_ACTION\x10\x9b\xc8\x02\x12*\n$ROS_COMMAND__POST_INSERTED_INTO_NOTE\x10\x9e\xc8\x02\x12$\n\x1eROS_COMMAND__AVAILABLE_ACTIONS\x10\x9f\xc8\x02\x12$\n\x1eROS__QUESTIONNAIRE__PRE_SEARCH\x10\x9c\xc8\x02\x12%\n\x1fROS__QUESTIONNAIRE__POST_SEARCH\x10\x9d\xc8\x02\x12,\n&SNOOZE_PROTOCOL_COMMAND__PRE_ORIGINATE\x10\xf8\xcf\x02\x12-\n\'SNOOZE_PROTOCOL_COMMAND__POST_ORIGINATE\x10\xf9\xcf\x02\x12)\n#SNOOZE_PROTOCOL_COMMAND__PRE_UPDATE\x10\xfa\xcf\x02\x12*\n$SNOOZE_PROTOCOL_COMMAND__POST_UPDATE\x10\xfb\xcf\x02\x12)\n#SNOOZE_PROTOCOL_COMMAND__PRE_COMMIT\x10\xfc\xcf\x02\x12*\n$SNOOZE_PROTOCOL_COMMAND__POST_COMMIT\x10\xfd\xcf\x02\x12)\n#SNOOZE_PROTOCOL_COMMAND__PRE_DELETE\x10\xfe\xcf\x02\x12*\n$SNOOZE_PROTOCOL_COMMAND__POST_DELETE\x10\xff\xcf\x02\x12\x31\n+SNOOZE_PROTOCOL_COMMAND__PRE_ENTER_IN_ERROR\x10\x80\xd0\x02\x12\x32\n,SNOOZE_PROTOCOL_COMMAND__POST_ENTER_IN_ERROR\x10\x81\xd0\x02\x12\x31\n+SNOOZE_PROTOCOL_COMMAND__PRE_EXECUTE_ACTION\x10\x82\xd0\x02\x12\x32\n,SNOOZE_PROTOCOL_COMMAND__POST_EXECUTE_ACTION\x10\x83\xd0\x02\x12\x36\n0SNOOZE_PROTOCOL_COMMAND__POST_INSERTED_INTO_NOTE\x10\x86\xd0\x02\x12\x30\n*SNOOZE_PROTOCOL_COMMAND__AVAILABLE_ACTIONS\x10\x87\xd0\x02\x12+\n%SNOOZE_PROTOCOL__PROTOCOL__PRE_SEARCH\x10\x84\xd0\x02\x12,\n&SNOOZE_PROTOCOL__PROTOCOL__POST_SEARCH\x10\x85\xd0\x02\x12,\n&STOP_MEDICATION_COMMAND__PRE_ORIGINATE\x10\xe0\xd7\x02\x12-\n\'STOP_MEDICATION_COMMAND__POST_ORIGINATE\x10\xe1\xd7\x02\x12)\n#STOP_MEDICATION_COMMAND__PRE_UPDATE\x10\xe2\xd7\x02\x12*\n$STOP_MEDICATION_COMMAND__POST_UPDATE\x10\xe3\xd7\x02\x12)\n#STOP_MEDICATION_COMMAND__PRE_COMMIT\x10\xe4\xd7\x02\x12*\n$STOP_MEDICATION_COMMAND__POST_COMMIT\x10\xe5\xd7\x02\x12)\n#STOP_MEDICATION_COMMAND__PRE_DELETE\x10\xe6\xd7\x02\x12*\n$STOP_MEDICATION_COMMAND__POST_DELETE\x10\xe7\xd7\x02\x12\x31\n+STOP_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR\x10\xe8\xd7\x02\x12\x32\n,STOP_MEDICATION_COMMAND__POST_ENTER_IN_ERROR\x10\xe9\xd7\x02\x12\x31\n+STOP_MEDICATION_COMMAND__PRE_EXECUTE_ACTION\x10\xea\xd7\x02\x12\x32\n,STOP_MEDICATION_COMMAND__POST_EXECUTE_ACTION\x10\xeb\xd7\x02\x12\x36\n0STOP_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE\x10\xef\xd7\x02\x12\x30\n*STOP_MEDICATION_COMMAND__AVAILABLE_ACTIONS\x10\xec\xd7\x02\x12-\n\'STOP_MEDICATION__MEDICATION__PRE_SEARCH\x10\xed\xd7\x02\x12.\n(STOP_MEDICATION__MEDICATION__POST_SEARCH\x10\xee\xd7\x02\x12\x32\n,STRUCTURED_ASSESSMENT_COMMAND__PRE_ORIGINATE\x10\xc8\xdf\x02\x12\x33\n-STRUCTURED_ASSESSMENT_COMMAND__POST_ORIGINATE\x10\xc9\xdf\x02\x12/\n)STRUCTURED_ASSESSMENT_COMMAND__PRE_UPDATE\x10\xca\xdf\x02\x12\x30\n*STRUCTURED_ASSESSMENT_COMMAND__POST_UPDATE\x10\xcb\xdf\x02\x12/\n)STRUCTURED_ASSESSMENT_COMMAND__PRE_COMMIT\x10\xcc\xdf\x02\x12\x30\n*STRUCTURED_ASSESSMENT_COMMAND__POST_COMMIT\x10\xcd\xdf\x02\x12/\n)STRUCTURED_ASSESSMENT_COMMAND__PRE_DELETE\x10\xce\xdf\x02\x12\x30\n*STRUCTURED_ASSESSMENT_COMMAND__POST_DELETE\x10\xcf\xdf\x02\x12\x37\n1STRUCTURED_ASSESSMENT_COMMAND__PRE_ENTER_IN_ERROR\x10\xd0\xdf\x02\x12\x38\n2STRUCTURED_ASSESSMENT_COMMAND__POST_ENTER_IN_ERROR\x10\xd1\xdf\x02\x12\x37\n1STRUCTURED_ASSESSMENT_COMMAND__PRE_EXECUTE_ACTION\x10\xd2\xdf\x02\x12\x38\n2STRUCTURED_ASSESSMENT_COMMAND__POST_EXECUTE_ACTION\x10\xd3\xdf\x02\x12<\n6STRUCTURED_ASSESSMENT_COMMAND__POST_INSERTED_INTO_NOTE\x10\xd6\xdf\x02\x12\x36\n0STRUCTURED_ASSESSMENT_COMMAND__AVAILABLE_ACTIONS\x10\xd7\xdf\x02\x12\x36\n0STRUCTURED_ASSESSMENT__QUESTIONNAIRE__PRE_SEARCH\x10\xd4\xdf\x02\x12\x37\n1STRUCTURED_ASSESSMENT__QUESTIONNAIRE__POST_SEARCH\x10\xd5\xdf\x02\x12-\n\'SURGICAL_HISTORY_COMMAND__PRE_ORIGINATE\x10\xb0\xe7\x02\x12.\n(SURGICAL_HISTORY_COMMAND__POST_ORIGINATE\x10\xb1\xe7\x02\x12*\n$SURGICAL_HISTORY_COMMAND__PRE_UPDATE\x10\xb2\xe7\x02\x12+\n%SURGICAL_HISTORY_COMMAND__POST_UPDATE\x10\xb3\xe7\x02\x12*\n$SURGICAL_HISTORY_COMMAND__PRE_COMMIT\x10\xb4\xe7\x02\x12+\n%SURGICAL_HISTORY_COMMAND__POST_COMMIT\x10\xb5\xe7\x02\x12*\n$SURGICAL_HISTORY_COMMAND__PRE_DELETE\x10\xb6\xe7\x02\x12+\n%SURGICAL_HISTORY_COMMAND__POST_DELETE\x10\xb7\xe7\x02\x12\x32\n,SURGICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR\x10\xb8\xe7\x02\x12\x33\n-SURGICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR\x10\xb9\xe7\x02\x12\x32\n,SURGICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION\x10\xba\xe7\x02\x12\x33\n-SURGICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION\x10\xbb\xe7\x02\x12\x37\n1SURGICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE\x10\xbe\xe7\x02\x12\x31\n+SURGICAL_HISTORY_COMMAND__AVAILABLE_ACTIONS\x10\xbf\xe7\x02\x12\x39\n3SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__PRE_SEARCH\x10\xbc\xe7\x02\x12:\n4SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__POST_SEARCH\x10\xbd\xe7\x02\x12!\n\x1bTASK_COMMAND__PRE_ORIGINATE\x10\x98\xef\x02\x12\"\n\x1cTASK_COMMAND__POST_ORIGINATE\x10\x99\xef\x02\x12\x1e\n\x18TASK_COMMAND__PRE_UPDATE\x10\x9a\xef\x02\x12\x1f\n\x19TASK_COMMAND__POST_UPDATE\x10\x9b\xef\x02\x12\x1e\n\x18TASK_COMMAND__PRE_COMMIT\x10\x9c\xef\x02\x12\x1f\n\x19TASK_COMMAND__POST_COMMIT\x10\x9d\xef\x02\x12\x1e\n\x18TASK_COMMAND__PRE_DELETE\x10\x9e\xef\x02\x12\x1f\n\x19TASK_COMMAND__POST_DELETE\x10\x9f\xef\x02\x12&\n TASK_COMMAND__PRE_ENTER_IN_ERROR\x10\xa0\xef\x02\x12\'\n!TASK_COMMAND__POST_ENTER_IN_ERROR\x10\xa1\xef\x02\x12&\n TASK_COMMAND__PRE_EXECUTE_ACTION\x10\xa2\xef\x02\x12\'\n!TASK_COMMAND__POST_EXECUTE_ACTION\x10\xa3\xef\x02\x12+\n%TASK_COMMAND__POST_INSERTED_INTO_NOTE\x10\xa8\xef\x02\x12%\n\x1fTASK_COMMAND__AVAILABLE_ACTIONS\x10\xa9\xef\x02\x12!\n\x1bTASK__ASSIGN_TO__PRE_SEARCH\x10\xa4\xef\x02\x12\"\n\x1cTASK__ASSIGN_TO__POST_SEARCH\x10\xa5\xef\x02\x12\x1e\n\x18TASK__LABELS__PRE_SEARCH\x10\xa6\xef\x02\x12\x1f\n\x19TASK__LABELS__POST_SEARCH\x10\xa7\xef\x02\x12-\n\'UPDATE_DIAGNOSIS_COMMAND__PRE_ORIGINATE\x10\xe8\xfe\x02\x12.\n(UPDATE_DIAGNOSIS_COMMAND__POST_ORIGINATE\x10\xe9\xfe\x02\x12*\n$UPDATE_DIAGNOSIS_COMMAND__PRE_UPDATE\x10\xea\xfe\x02\x12+\n%UPDATE_DIAGNOSIS_COMMAND__POST_UPDATE\x10\xeb\xfe\x02\x12*\n$UPDATE_DIAGNOSIS_COMMAND__PRE_COMMIT\x10\xec\xfe\x02\x12+\n%UPDATE_DIAGNOSIS_COMMAND__POST_COMMIT\x10\xed\xfe\x02\x12*\n$UPDATE_DIAGNOSIS_COMMAND__PRE_DELETE\x10\xee\xfe\x02\x12+\n%UPDATE_DIAGNOSIS_COMMAND__POST_DELETE\x10\xef\xfe\x02\x12\x32\n,UPDATE_DIAGNOSIS_COMMAND__PRE_ENTER_IN_ERROR\x10\xf0\xfe\x02\x12\x33\n-UPDATE_DIAGNOSIS_COMMAND__POST_ENTER_IN_ERROR\x10\xf1\xfe\x02\x12\x32\n,UPDATE_DIAGNOSIS_COMMAND__PRE_EXECUTE_ACTION\x10\xf2\xfe\x02\x12\x33\n-UPDATE_DIAGNOSIS_COMMAND__POST_EXECUTE_ACTION\x10\xf3\xfe\x02\x12\x37\n1UPDATE_DIAGNOSIS_COMMAND__POST_INSERTED_INTO_NOTE\x10\xf8\xfe\x02\x12\x31\n+UPDATE_DIAGNOSIS_COMMAND__AVAILABLE_ACTIONS\x10\xf9\xfe\x02\x12-\n\'UPDATE_DIAGNOSIS__CONDITION__PRE_SEARCH\x10\xf4\xfe\x02\x12.\n(UPDATE_DIAGNOSIS__CONDITION__POST_SEARCH\x10\xf5\xfe\x02\x12\x31\n+UPDATE_DIAGNOSIS__NEW_CONDITION__PRE_SEARCH\x10\xf6\xfe\x02\x12\x32\n,UPDATE_DIAGNOSIS__NEW_CONDITION__POST_SEARCH\x10\xf7\xfe\x02\x12(\n\"UPDATE_GOAL_COMMAND__PRE_ORIGINATE\x10\xd0\x86\x03\x12)\n#UPDATE_GOAL_COMMAND__POST_ORIGINATE\x10\xd1\x86\x03\x12%\n\x1fUPDATE_GOAL_COMMAND__PRE_UPDATE\x10\xd2\x86\x03\x12&\n UPDATE_GOAL_COMMAND__POST_UPDATE\x10\xd3\x86\x03\x12%\n\x1fUPDATE_GOAL_COMMAND__PRE_COMMIT\x10\xd4\x86\x03\x12&\n UPDATE_GOAL_COMMAND__POST_COMMIT\x10\xd5\x86\x03\x12%\n\x1fUPDATE_GOAL_COMMAND__PRE_DELETE\x10\xd6\x86\x03\x12&\n UPDATE_GOAL_COMMAND__POST_DELETE\x10\xd7\x86\x03\x12-\n\'UPDATE_GOAL_COMMAND__PRE_ENTER_IN_ERROR\x10\xd8\x86\x03\x12.\n(UPDATE_GOAL_COMMAND__POST_ENTER_IN_ERROR\x10\xd9\x86\x03\x12-\n\'UPDATE_GOAL_COMMAND__PRE_EXECUTE_ACTION\x10\xda\x86\x03\x12.\n(UPDATE_GOAL_COMMAND__POST_EXECUTE_ACTION\x10\xdb\x86\x03\x12\x32\n,UPDATE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE\x10\xdc\x86\x03\x12,\n&UPDATE_GOAL_COMMAND__AVAILABLE_ACTIONS\x10\xdf\x86\x03\x12-\n\'UPDATE_GOAL__GOAL_STATEMENT__PRE_SEARCH\x10\xdd\x86\x03\x12.\n(UPDATE_GOAL__GOAL_STATEMENT__POST_SEARCH\x10\xde\x86\x03\x12#\n\x1dVITALS_COMMAND__PRE_ORIGINATE\x10\xa0\x96\x03\x12$\n\x1eVITALS_COMMAND__POST_ORIGINATE\x10\xa1\x96\x03\x12 \n\x1aVITALS_COMMAND__PRE_UPDATE\x10\xa2\x96\x03\x12!\n\x1bVITALS_COMMAND__POST_UPDATE\x10\xa3\x96\x03\x12 \n\x1aVITALS_COMMAND__PRE_COMMIT\x10\xa4\x96\x03\x12!\n\x1bVITALS_COMMAND__POST_COMMIT\x10\xa5\x96\x03\x12 \n\x1aVITALS_COMMAND__PRE_DELETE\x10\xa6\x96\x03\x12!\n\x1bVITALS_COMMAND__POST_DELETE\x10\xa7\x96\x03\x12(\n\"VITALS_COMMAND__PRE_ENTER_IN_ERROR\x10\xa8\x96\x03\x12)\n#VITALS_COMMAND__POST_ENTER_IN_ERROR\x10\xa9\x96\x03\x12(\n\"VITALS_COMMAND__PRE_EXECUTE_ACTION\x10\xaa\x96\x03\x12)\n#VITALS_COMMAND__POST_EXECUTE_ACTION\x10\xab\x96\x03\x12-\n\'VITALS_COMMAND__POST_INSERTED_INTO_NOTE\x10\xac\x96\x03\x12\'\n!VITALS_COMMAND__AVAILABLE_ACTIONS\x10\xad\x96\x03\x12.\n(ASSESS_CODING_GAP_COMMAND__PRE_ORIGINATE\x10\xa8\xbd\x03\x12/\n)ASSESS_CODING_GAP_COMMAND__POST_ORIGINATE\x10\xa9\xbd\x03\x12+\n%ASSESS_CODING_GAP_COMMAND__PRE_UPDATE\x10\xaa\xbd\x03\x12,\n&ASSESS_CODING_GAP_COMMAND__POST_UPDATE\x10\xab\xbd\x03\x12+\n%ASSESS_CODING_GAP_COMMAND__PRE_COMMIT\x10\xac\xbd\x03\x12,\n&ASSESS_CODING_GAP_COMMAND__POST_COMMIT\x10\xad\xbd\x03\x12+\n%ASSESS_CODING_GAP_COMMAND__PRE_DELETE\x10\xae\xbd\x03\x12,\n&ASSESS_CODING_GAP_COMMAND__POST_DELETE\x10\xaf\xbd\x03\x12\x33\n-ASSESS_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR\x10\xb0\xbd\x03\x12\x34\n.ASSESS_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR\x10\xb1\xbd\x03\x12\x33\n-ASSESS_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION\x10\xb2\xbd\x03\x12\x34\n.ASSESS_CODING_GAP_COMMAND__POST_EXECUTE_ACTION\x10\xb3\xbd\x03\x12\x38\n2ASSESS_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE\x10\xb6\xbd\x03\x12\x32\n,ASSESS_CODING_GAP_COMMAND__AVAILABLE_ACTIONS\x10\xb7\xbd\x03\x12-\n\'ASSESS_CODING_GAP__DIAGNOSE__PRE_SEARCH\x10\xb4\xbd\x03\x12.\n(ASSESS_CODING_GAP__DIAGNOSE__POST_SEARCH\x10\xb5\xbd\x03\x12.\n(CREATE_CODING_GAP_COMMAND__PRE_ORIGINATE\x10\x90\xc5\x03\x12/\n)CREATE_CODING_GAP_COMMAND__POST_ORIGINATE\x10\x91\xc5\x03\x12+\n%CREATE_CODING_GAP_COMMAND__PRE_UPDATE\x10\x92\xc5\x03\x12,\n&CREATE_CODING_GAP_COMMAND__POST_UPDATE\x10\x93\xc5\x03\x12+\n%CREATE_CODING_GAP_COMMAND__PRE_COMMIT\x10\x94\xc5\x03\x12,\n&CREATE_CODING_GAP_COMMAND__POST_COMMIT\x10\x95\xc5\x03\x12+\n%CREATE_CODING_GAP_COMMAND__PRE_DELETE\x10\x96\xc5\x03\x12,\n&CREATE_CODING_GAP_COMMAND__POST_DELETE\x10\x97\xc5\x03\x12\x33\n-CREATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR\x10\x98\xc5\x03\x12\x34\n.CREATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR\x10\x99\xc5\x03\x12\x33\n-CREATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION\x10\x9a\xc5\x03\x12\x34\n.CREATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION\x10\x9b\xc5\x03\x12\x38\n2CREATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE\x10\x9e\xc5\x03\x12\x32\n,CREATE_CODING_GAP_COMMAND__AVAILABLE_ACTIONS\x10\x9f\xc5\x03\x12-\n\'CREATE_CODING_GAP__DIAGNOSE__PRE_SEARCH\x10\x9c\xc5\x03\x12.\n(CREATE_CODING_GAP__DIAGNOSE__POST_SEARCH\x10\x9d\xc5\x03\x12\x30\n*VALIDATE_CODING_GAP_COMMAND__PRE_ORIGINATE\x10\xf8\xcc\x03\x12\x31\n+VALIDATE_CODING_GAP_COMMAND__POST_ORIGINATE\x10\xf9\xcc\x03\x12-\n\'VALIDATE_CODING_GAP_COMMAND__PRE_UPDATE\x10\xfa\xcc\x03\x12.\n(VALIDATE_CODING_GAP_COMMAND__POST_UPDATE\x10\xfb\xcc\x03\x12-\n\'VALIDATE_CODING_GAP_COMMAND__PRE_COMMIT\x10\xfc\xcc\x03\x12.\n(VALIDATE_CODING_GAP_COMMAND__POST_COMMIT\x10\xfd\xcc\x03\x12-\n\'VALIDATE_CODING_GAP_COMMAND__PRE_DELETE\x10\xfe\xcc\x03\x12.\n(VALIDATE_CODING_GAP_COMMAND__POST_DELETE\x10\xff\xcc\x03\x12\x35\n/VALIDATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR\x10\x80\xcd\x03\x12\x36\n0VALIDATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR\x10\x81\xcd\x03\x12\x35\n/VALIDATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION\x10\x82\xcd\x03\x12\x36\n0VALIDATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION\x10\x83\xcd\x03\x12:\n4VALIDATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE\x10\x84\xcd\x03\x12\x34\n.VALIDATE_CODING_GAP_COMMAND__AVAILABLE_ACTIONS\x10\x85\xcd\x03\x12-\n\'DEFER_CODING_GAP_COMMAND__PRE_ORIGINATE\x10\xe0\xd4\x03\x12.\n(DEFER_CODING_GAP_COMMAND__POST_ORIGINATE\x10\xe1\xd4\x03\x12*\n$DEFER_CODING_GAP_COMMAND__PRE_UPDATE\x10\xe2\xd4\x03\x12+\n%DEFER_CODING_GAP_COMMAND__POST_UPDATE\x10\xe3\xd4\x03\x12*\n$DEFER_CODING_GAP_COMMAND__PRE_COMMIT\x10\xe4\xd4\x03\x12+\n%DEFER_CODING_GAP_COMMAND__POST_COMMIT\x10\xe5\xd4\x03\x12*\n$DEFER_CODING_GAP_COMMAND__PRE_DELETE\x10\xe6\xd4\x03\x12+\n%DEFER_CODING_GAP_COMMAND__POST_DELETE\x10\xe7\xd4\x03\x12\x32\n,DEFER_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR\x10\xe8\xd4\x03\x12\x33\n-DEFER_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR\x10\xe9\xd4\x03\x12\x32\n,DEFER_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION\x10\xea\xd4\x03\x12\x33\n-DEFER_CODING_GAP_COMMAND__POST_EXECUTE_ACTION\x10\xeb\xd4\x03\x12\x37\n1DEFER_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE\x10\xec\xd4\x03\x12\x31\n+DEFER_CODING_GAP_COMMAND__AVAILABLE_ACTIONS\x10\xed\xd4\x03\x12.\n(CHANGE_MEDICATION_COMMAND__PRE_ORIGINATE\x10\xc8\xdc\x03\x12/\n)CHANGE_MEDICATION_COMMAND__POST_ORIGINATE\x10\xc9\xdc\x03\x12+\n%CHANGE_MEDICATION_COMMAND__PRE_UPDATE\x10\xca\xdc\x03\x12,\n&CHANGE_MEDICATION_COMMAND__POST_UPDATE\x10\xcb\xdc\x03\x12+\n%CHANGE_MEDICATION_COMMAND__PRE_COMMIT\x10\xcc\xdc\x03\x12,\n&CHANGE_MEDICATION_COMMAND__POST_COMMIT\x10\xcd\xdc\x03\x12+\n%CHANGE_MEDICATION_COMMAND__PRE_DELETE\x10\xce\xdc\x03\x12,\n&CHANGE_MEDICATION_COMMAND__POST_DELETE\x10\xcf\xdc\x03\x12\x33\n-CHANGE_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR\x10\xd0\xdc\x03\x12\x34\n.CHANGE_MEDICATION_COMMAND__POST_ENTER_IN_ERROR\x10\xd1\xdc\x03\x12\x33\n-CHANGE_MEDICATION_COMMAND__PRE_EXECUTE_ACTION\x10\xd2\xdc\x03\x12\x34\n.CHANGE_MEDICATION_COMMAND__POST_EXECUTE_ACTION\x10\xd3\xdc\x03\x12\x38\n2CHANGE_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE\x10\xd4\xdc\x03\x12\x32\n,CHANGE_MEDICATION_COMMAND__AVAILABLE_ACTIONS\x10\xd7\xdc\x03\x12/\n)CHANGE_MEDICATION__MEDICATION__PRE_SEARCH\x10\xd5\xdc\x03\x12\x30\n*CHANGE_MEDICATION__MEDICATION__POST_SEARCH\x10\xd6\xdc\x03\x12\x1d\n\x17SHOW_NOTE_HEADER_BUTTON\x10\xf0\xa2\x04\x12\x1d\n\x17SHOW_NOTE_FOOTER_BUTTON\x10\xf1\xa2\x04\x12\x1b\n\x15\x41\x43TION_BUTTON_CLICKED\x10\xf2\xa2\x04\x12\x1f\n\x19PATIENT_CHART__CONDITIONS\x10\xa0\x8d\x06\x12$\n\x1ePATIENT_CHART__DETECTED_ISSUES\x10\xa5\x8d\x06\x12\x32\n,PATIENT_CHART_SUMMARY__SECTION_CONFIGURATION\x10\xa1\x8d\x06\x12,\n&PATIENT_PROFILE__SECTION_CONFIGURATION\x10\xa2\x8d\x06\x12\x30\n*PATIENT_PROFILE__ADD_PHARMACY__POST_SEARCH\x10\xa3\x8d\x06\x12 \n\x1aPATIENT_CHART__MEDICATIONS\x10\xa4\x8d\x06\x12\x17\n\x11\x43LAIM__CONDITIONS\x10\x88\x95\x06\x12\x14\n\x0ePLUGIN_CREATED\x10\xf0\x9c\x06\x12\x14\n\x0ePLUGIN_UPDATED\x10\xf1\x9c\x06\x12\x1a\n\x14\x41PPLICATION__ON_OPEN\x10\xd8\xa4\x06\x12$\n\x1e\x41PPLICATION__ON_CONTEXT_CHANGE\x10\xd9\xa4\x06\x12\x1f\n\x19PATIENT_PORTAL__GET_FORMS\x10\xb0\xdb\x06\x12*\n$PATIENT_PORTAL__APPOINTMENT_CANCELED\x10\xb1\xdb\x06\x12-\n\'PATIENT_PORTAL__APPOINTMENT_RESCHEDULED\x10\xb2\xdb\x06\x12\x31\n+PATIENT_PORTAL__APPOINTMENT_CAN_BE_CANCELED\x10\xb3\xdb\x06\x12\x34\n.PATIENT_PORTAL__APPOINTMENT_CAN_BE_RESCHEDULED\x10\xb4\xdb\x06\x12\x36\n0PATIENT_PORTAL__APPOINTMENTS__SLOTS__POST_SEARCH\x10\xb5\xdb\x06\x12\x46\n@PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__PRE_SEARCH\x10\xb6\xdb\x06\x12G\nAPATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__POST_SEARCH\x10\xb7\xdb\x06\x12>\n8PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__PRE_SEARCH\x10\xb8\xdb\x06\x12?\n9PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__POST_SEARCH\x10\xb9\xdb\x06\x12>\n8PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__PRE_SEARCH\x10\xba\xdb\x06\x12?\n9PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__POST_SEARCH\x10\xbb\xdb\x06\x12\x37\n1PATIENT_PORTAL__APPOINTMENT_CAN_SHOW_MEETING_LINK\x10\xbc\xdb\x06\x12\x33\n-PATIENT_PORTAL__GET_APPLICATION_CONFIGURATION\x10\xbd\xdb\x06\x12(\n\"PATIENT_PORTAL__MENU_CONFIGURATION\x10\x94\xdc\x06\x12*\n$PATIENT_PORTAL__WIDGET_CONFIGURATION\x10\x95\xdc\x06\x12;\n5SHOW_CHART_SUMMARY_SOCIAL_DETERMINANTS_SECTION_BUTTON\x10\xc0\xa9\x07\x12-\n\'SHOW_CHART_SUMMARY_GOALS_SECTION_BUTTON\x10\xc1\xa9\x07\x12\x32\n,SHOW_CHART_SUMMARY_CONDITIONS_SECTION_BUTTON\x10\xc2\xa9\x07\x12\x33\n-SHOW_CHART_SUMMARY_MEDICATIONS_SECTION_BUTTON\x10\xc3\xa9\x07\x12\x31\n+SHOW_CHART_SUMMARY_ALLERGIES_SECTION_BUTTON\x10\xc4\xa9\x07\x12\x32\n,SHOW_CHART_SUMMARY_CARE_TEAMS_SECTION_BUTTON\x10\xc5\xa9\x07\x12.\n(SHOW_CHART_SUMMARY_VITALS_SECTION_BUTTON\x10\xc6\xa9\x07\x12\x35\n/SHOW_CHART_SUMMARY_IMMUNIZATIONS_SECTION_BUTTON\x10\xc7\xa9\x07\x12\x38\n2SHOW_CHART_SUMMARY_SURGICAL_HISTORY_SECTION_BUTTON\x10\xc8\xa9\x07\x12\x36\n0SHOW_CHART_SUMMARY_FAMILY_HISTORY_SECTION_BUTTON\x10\xc9\xa9\x07\x12\x33\n-SHOW_CHART_SUMMARY_CODING_GAPS_SECTION_BUTTON\x10\xca\xa9\x07\x12\x1d\n\x17SIMPLE_API_AUTHENTICATE\x10\xd0\xf7\x07\x12\x18\n\x12SIMPLE_API_REQUEST\x10\xd1\xf7\x07\x12\'\n!SIMPLE_API_WEBSOCKET_AUTHENTICATE\x10\xd2\xf7\x07\x12-\n\'PATIENT_METADATA__GET_ADDITIONAL_FIELDS\x10\xe0\xc5\x08\x12)\n#PATIENT_EXTERNAL_IDENTIFIER_CREATED\x10\xe1\xc5\x08\x12)\n#PATIENT_EXTERNAL_IDENTIFIER_UPDATED\x10\xe2\xc5\x08\x12)\n#PATIENT_EXTERNAL_IDENTIFIER_DELETED\x10\xe3\xc5\x08\x12\x1e\n\x18PATIENT_METADATA_CREATED\x10\xe4\xc5\x08\x12\x1e\n\x18PATIENT_METADATA_UPDATED\x10\xe5\xc5\x08\x12.\n(APPOINTMENT__FORM__PROVIDERS__PRE_SEARCH\x10\xc8\xcd\x08\x12.\n(APPOINTMENT__FORM__LOCATIONS__PRE_SEARCH\x10\xc9\xcd\x08\x12\x30\n*APPOINTMENT__FORM__VISIT_TYPES__PRE_SEARCH\x10\xca\xcd\x08\x12.\n(APPOINTMENT__FORM__DURATIONS__PRE_SEARCH\x10\xcb\xcd\x08\x12\x35\n/APPOINTMENT__FORM__REASON_FOR_VISIT__PRE_SEARCH\x10\xcc\xcd\x08\x12/\n)APPOINTMENT__FORM__PROVIDERS__POST_SEARCH\x10\xce\xcd\x08\x12/\n)APPOINTMENT__FORM__LOCATIONS__POST_SEARCH\x10\xcf\xcd\x08\x12\x31\n+APPOINTMENT__FORM__VISIT_TYPES__POST_SEARCH\x10\xd0\xcd\x08\x12/\n)APPOINTMENT__FORM__DURATIONS__POST_SEARCH\x10\xd1\xcd\x08\x12\x36\n0APPOINTMENT__FORM__REASON_FOR_VISIT__POST_SEARCH\x10\xd2\xcd\x08\x12.\n(APPOINTMENT__FORM__GET_ADDITIONAL_FIELDS\x10\xd3\xcd\x08\x12%\n\x1f\x41PPOINTMENT__SLOTS__POST_SEARCH\x10\xd4\xcd\x08\x12\"\n\x1c\x41PPOINTMENT_METADATA_CREATED\x10\xac\xce\x08\x12\"\n\x1c\x41PPOINTMENT_METADATA_UPDATED\x10\xb7\xce\x08\x12 \n\x1a\x44OCUMENT_REFERENCE_CREATED\x10\xf0\x93\t\x12 \n\x1a\x44OCUMENT_REFERENCE_UPDATED\x10\xf1\x93\t\x12 \n\x1a\x44OCUMENT_REFERENCE_DELETED\x10\xf2\x93\t\x12!\n\x1cPANEL_SECTIONS_CONFIGURATION\x10\xfcu\x12&\n REVENUE__PAYMENT_PROCESSOR__LIST\x10\x81\xe2\t\x12(\n\"REVENUE__PAYMENT_PROCESSOR__CHARGE\x10\x83\xe2\t\x12*\n$REVENUE__PAYMENT_PROCESSOR__SELECTED\x10\x82\xe2\t\x12\x37\n1REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHODS__LIST\x10\x84\xe2\t\x12\x36\n0REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHODS__ADD\x10\x85\xe2\t\x12\x39\n3REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHODS__REMOVE\x10\x86\xe2\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'canvas_generated.messages.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EVENTTYPE']._serialized_start=256
  _globals['_EVENTTYPE']._serialized_end=40293
  _globals['_EVENT']._serialized_start=91
  _globals['_EVENT']._serialized_end=185
  _globals['_EVENTRESPONSE']._serialized_start=187
  _globals['_EVENTRESPONSE']._serialized_end=252
# @@protoc_insertion_point(module_scope)
