syntax = 'proto3';

import "canvas_generated/messages/effects.proto";

package canvas;

enum EventType {
  UNKNOWN = 0;

  // Workflow kit-inspired events

  ALLERGY_INTOLERANCE_CREATED = 1;
  ALLERGY_INTOLERANCE_UPDATED = 2;
  APPOINTMENT_CANCELED = 4;
  APPOINTMENT_CHECKED_IN = 5;
  APPOINTMENT_CREATED = 6;
  APPOINTMENT_NO_SHOWED = 7;
  APPOINTMENT_RESCHEDULED = 8;
  APPOINTMENT_RESTORED = 9;
  APPOINTMENT_UPDATED = 10;
  BILLING_LINE_ITEM_CREATED = 11;
  BILLING_LINE_ITEM_UPDATED = 12;
  CONDITION_ASSESSED = 13;
  CONDITION_CREATED = 14;
  CONDITION_RESOLVED = 15;
  CONDITION_UPDATED = 16;
  CONSENT_CREATED = 17;
  CONSENT_DELETED = 18;
  CONSENT_UPDATED = 19;
  COVERAGE_CREATED = 20;
  COVERAGE_UPDATED = 21;
  ENCOUNTER_CREATED = 22;
  ENCOUNTER_UPDATED = 23;
  IMAGING_REPORT_CREATED = 26;
  IMAGING_REPORT_UPDATED = 27;
  IMMUNIZATION_CREATED = 28;
  IMMUNIZATION_STATEMENT_CREATED = 29;
  IMMUNIZATION_STATEMENT_UPDATED = 30;
  IMMUNIZATION_UPDATED = 31;
  INSTRUCTION_CREATED = 32;
  INSTRUCTION_UPDATED = 33;
  INTERVIEW_CREATED = 34;
  INTERVIEW_UPDATED = 35;
  LAB_ORDER_CREATED = 36;
  LAB_ORDER_UPDATED = 37;
  LAB_REPORT_CREATED = 38;
  LAB_REPORT_UPDATED = 39;
  MEDICATION_LIST_ITEM_CREATED = 40;
  MEDICATION_LIST_ITEM_UPDATED = 41;
  MESSAGE_CREATED = 42;
  MESSAGE_TRANSMISSION_CREATED = 53;
  MESSAGE_TRANSMISSION_UPDATED = 56;
  PATIENT_CREATED = 43;
  PATIENT_UPDATED = 44;
  PRESCRIPTION_CREATED = 45;
  PRESCRIPTION_UPDATED = 46;
  REFERRAL_REPORT_CREATED = 47;
  REFERRAL_REPORT_UPDATED = 48;
  STAFF_CREATED = 49;
  STAFF_UPDATED = 50;
  TASK_COMMENT_CREATED = 51;
  TASK_CREATED = 54;
  TASK_LABELS_ADJUSTED = 55;
  TASK_UPDATED = 57;
  VITAL_SIGN_CREATED = 58;
  VITAL_SIGN_UPDATED = 59;

  CRON = 60;

  // TODO: Confirm what these names should be and what numbers they should occupy, and whether to leave space for more
  CARE_TEAM_MEMBERSHIP_CREATED = 61;
  CARE_TEAM_MEMBERSHIP_UPDATED = 62;
  CARE_TEAM_MEMBERSHIP_DELETED = 63;
  NOTE_STATE_CHANGE_EVENT_CREATED = 64;
  NOTE_STATE_CHANGE_EVENT_UPDATED = 65;
  PATIENT_ADDRESS_CREATED = 66;
  PATIENT_ADDRESS_UPDATED = 67;
  PATIENT_ADDRESS_DELETED = 68;
  PATIENT_CONTACT_PERSON_CREATED = 69;
  PATIENT_CONTACT_PERSON_UPDATED = 70;
  PATIENT_CONTACT_PERSON_DELETED = 71;
  PATIENT_CONTACT_POINT_CREATED = 72;
  PATIENT_CONTACT_POINT_UPDATED = 73;
  PATIENT_CONTACT_POINT_DELETED = 74;
  PROTOCOL_OVERRIDE_CREATED = 75;
  PROTOCOL_OVERRIDE_UPDATED = 76;
  PROTOCOL_OVERRIDE_DELETED = 77;
  TASK_COMMENT_UPDATED = 78;
  TASK_COMMENT_DELETED = 79;

  DEVICE_CREATED = 80;
  DEVICE_UPDATED = 81;
  OBSERVATION_CREATED = 82;
  OBSERVATION_UPDATED = 83;

  DETECTED_ISSUE_CREATED = 84;
  DETECTED_ISSUE_UPDATED = 85;

  TASK_CLOSED = 86;
  TASK_COMPLETED = 87;
  TASK_METADATA_CREATED = 96;
  TASK_METADATA_UPDATED = 97;

  DETECTED_ISSUE_EVIDENCE_CREATED = 88;
  DETECTED_ISSUE_EVIDENCE_UPDATED = 89;

  STAFF_ACTIVATED = 90;
  STAFF_DEACTIVATED = 91;

  COMPOUND_MEDICATION_CREATED = 92;
  COMPOUND_MEDICATION_UPDATED = 93;

  APPOINTMENT_LABEL_ADDED = 94;
  APPOINTMENT_LABEL_REMOVED = 95;

  // General Command Events

  PRE_COMMAND_ORIGINATE = 100;
  POST_COMMAND_ORIGINATE = 101;
  PRE_COMMAND_UPDATE = 102;
  POST_COMMAND_UPDATE = 103;
  PRE_COMMAND_COMMIT = 104;
  POST_COMMAND_COMMIT = 105;
  PRE_COMMAND_DELETE = 106;
  POST_COMMAND_DELETE = 107;
  PRE_COMMAND_ENTER_IN_ERROR = 108;
  POST_COMMAND_ENTER_IN_ERROR = 109;
  PRE_COMMAND_EXECUTE_ACTION = 110;
  POST_COMMAND_EXECUTE_ACTION = 111;
  POST_COMMAND_INSERTED_INTO_NOTE = 112;

  // SSO hooks

  SSO__PROCESS_ADDITIONAL_REQUEST_DATA = 150;
  SSO__GET_POST_LOGIN_REDIRECT = 151;

  // Command-specific events

  ASSESS_COMMAND__CONDITION_SELECTED = 200;

  MEDICATION_STATEMENT__MEDICATION__PRE_SEARCH = 201;
  MEDICATION_STATEMENT__MEDICATION__POST_SEARCH = 202;
  MEDICATION_STATEMENT__MEDICATION__SELECTED = 203;

  // Specific Command event types.
  // The commented lines are event types for commands that are not available yet.

  // ADJUST_DIAGNOSIS_COMMAND__PRE_ORIGINATE = 1000;
  // ADJUST_DIAGNOSIS_COMMAND__POST_ORIGINATE = 1001;
  // ADJUST_DIAGNOSIS_COMMAND__PRE_UPDATE = 1002;
  // ADJUST_DIAGNOSIS_COMMAND__POST_UPDATE = 1003;
  // ADJUST_DIAGNOSIS_COMMAND__PRE_COMMIT = 1004;
  // ADJUST_DIAGNOSIS_COMMAND__POST_COMMIT = 1005;
  // ADJUST_DIAGNOSIS_COMMAND__PRE_DELETE = 1006;
  // ADJUST_DIAGNOSIS_COMMAND__POST_DELETE = 1007;
  // ADJUST_DIAGNOSIS_COMMAND__PRE_ENTER_IN_ERROR = 1008;
  // ADJUST_DIAGNOSIS_COMMAND__POST_ENTER_IN_ERROR = 1009;
  // ADJUST_DIAGNOSIS_COMMAND__PRE_EXECUTE_ACTION = 1010;
  // ADJUST_DIAGNOSIS_COMMAND__POST_EXECUTE_ACTION = 1011;

   ADJUST_PRESCRIPTION_COMMAND__PRE_ORIGINATE = 2000;
   ADJUST_PRESCRIPTION_COMMAND__POST_ORIGINATE = 2001;
   ADJUST_PRESCRIPTION_COMMAND__PRE_UPDATE = 2002;
   ADJUST_PRESCRIPTION_COMMAND__POST_UPDATE = 2003;
   ADJUST_PRESCRIPTION_COMMAND__PRE_COMMIT = 2004;
   ADJUST_PRESCRIPTION_COMMAND__POST_COMMIT = 2005;
   ADJUST_PRESCRIPTION_COMMAND__PRE_DELETE = 2006;
   ADJUST_PRESCRIPTION_COMMAND__POST_DELETE = 2007;
   ADJUST_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR = 2008;
   ADJUST_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR = 2009;
   ADJUST_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION = 2010;
   ADJUST_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION = 2011;
   ADJUST_PRESCRIPTION_COMMAND__POST_INSERTED_INTO_NOTE = 2020;
   ADJUST_PRESCRIPTION_COMMAND__AVAILABLE_ACTIONS = 2023;
   ADJUST_PRESCRIPTION__PRESCRIBE__POST_SEARCH = 2012;
   ADJUST_PRESCRIPTION__PRESCRIBE__PRE_SEARCH = 2013;
   ADJUST_PRESCRIPTION__INDICATIONS__PRE_SEARCH = 2014;
   ADJUST_PRESCRIPTION__INDICATIONS__POST_SEARCH = 2015;
   ADJUST_PRESCRIPTION__PHARMACY__PRE_SEARCH = 2016;
   ADJUST_PRESCRIPTION__PHARMACY__POST_SEARCH = 2017;
   ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__PRE_SEARCH = 2018;
   ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__POST_SEARCH = 2019;
   ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__PRE_SEARCH = 2021;
   ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__POST_SEARCH = 2022;
   ADJUST_PRESCRIPTION__PRESCRIBER__PRE_SEARCH = 2025;
   ADJUST_PRESCRIPTION__PRESCRIBER__POST_SEARCH = 2026;

  // ADJUST_PROTOCOL_COMMAND__PRE_ORIGINATE = 3000;
  // ADJUST_PROTOCOL_COMMAND__POST_ORIGINATE = 3001;
  // ADJUST_PROTOCOL_COMMAND__PRE_UPDATE = 3002;
  // ADJUST_PROTOCOL_COMMAND__POST_UPDATE = 3003;
  // ADJUST_PROTOCOL_COMMAND__PRE_COMMIT = 3004;
  // ADJUST_PROTOCOL_COMMAND__POST_COMMIT = 3005;
  // ADJUST_PROTOCOL_COMMAND__PRE_DELETE = 3006;
  // ADJUST_PROTOCOL_COMMAND__POST_DELETE = 3007;
  // ADJUST_PROTOCOL_COMMAND__PRE_ENTER_IN_ERROR = 3008;
  // ADJUST_PROTOCOL_COMMAND__POST_ENTER_IN_ERROR = 3009;
  // ADJUST_PROTOCOL_COMMAND__PRE_EXECUTE_ACTION = 3010;
  // ADJUST_PROTOCOL_COMMAND__POST_EXECUTE_ACTION = 3011;

  ALLERGY_COMMAND__PRE_ORIGINATE = 4000;
  ALLERGY_COMMAND__POST_ORIGINATE = 4001;
  ALLERGY_COMMAND__PRE_UPDATE = 4002;
  ALLERGY_COMMAND__POST_UPDATE = 4003;
  ALLERGY_COMMAND__PRE_COMMIT = 4004;
  ALLERGY_COMMAND__POST_COMMIT = 4005;
  ALLERGY_COMMAND__PRE_DELETE = 4006;
  ALLERGY_COMMAND__POST_DELETE = 4007;
  ALLERGY_COMMAND__PRE_ENTER_IN_ERROR = 4008;
  ALLERGY_COMMAND__POST_ENTER_IN_ERROR = 4009;
  ALLERGY_COMMAND__PRE_EXECUTE_ACTION = 4010;
  ALLERGY_COMMAND__POST_EXECUTE_ACTION = 4011;
  ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE = 4014;
  ALLERGY_COMMAND__AVAILABLE_ACTIONS = 4015;
  ALLERGY__ALLERGY__PRE_SEARCH = 4012;
  ALLERGY__ALLERGY__POST_SEARCH = 4013;

  // APPROVE_CHANGE_COMMAND__PRE_ORIGINATE = 5000;
  // APPROVE_CHANGE_COMMAND__POST_ORIGINATE = 5001;
  // APPROVE_CHANGE_COMMAND__PRE_UPDATE = 5002;
  // APPROVE_CHANGE_COMMAND__POST_UPDATE = 5003;
  // APPROVE_CHANGE_COMMAND__PRE_COMMIT = 5004;
  // APPROVE_CHANGE_COMMAND__POST_COMMIT = 5005;
  // APPROVE_CHANGE_COMMAND__PRE_DELETE = 5006;
  // APPROVE_CHANGE_COMMAND__POST_DELETE = 5007;
  // APPROVE_CHANGE_COMMAND__PRE_ENTER_IN_ERROR = 5008;
  // APPROVE_CHANGE_COMMAND__POST_ENTER_IN_ERROR = 5009;
  // APPROVE_CHANGE_COMMAND__PRE_EXECUTE_ACTION = 5010;
  // APPROVE_CHANGE_COMMAND__POST_EXECUTE_ACTION = 5011;

  // APPROVE_REFILL_COMMAND__PRE_ORIGINATE = 6000;
  // APPROVE_REFILL_COMMAND__POST_ORIGINATE = 6001;
  // APPROVE_REFILL_COMMAND__PRE_UPDATE = 6002;
  // APPROVE_REFILL_COMMAND__POST_UPDATE = 6003;
  // APPROVE_REFILL_COMMAND__PRE_COMMIT = 6004;
  // APPROVE_REFILL_COMMAND__POST_COMMIT = 6005;
  // APPROVE_REFILL_COMMAND__PRE_DELETE = 6006;
  // APPROVE_REFILL_COMMAND__POST_DELETE = 6007;
  // APPROVE_REFILL_COMMAND__PRE_ENTER_IN_ERROR = 6008;
  // APPROVE_REFILL_COMMAND__POST_ENTER_IN_ERROR = 6009;
  // APPROVE_REFILL_COMMAND__PRE_EXECUTE_ACTION = 6010;
  // APPROVE_REFILL_COMMAND__POST_EXECUTE_ACTION = 6011;

  ASSESS_COMMAND__PRE_ORIGINATE = 7000;
  ASSESS_COMMAND__POST_ORIGINATE = 7001;
  ASSESS_COMMAND__PRE_UPDATE = 7002;
  ASSESS_COMMAND__POST_UPDATE = 7003;
  ASSESS_COMMAND__PRE_COMMIT = 7004;
  ASSESS_COMMAND__POST_COMMIT = 7005;
  ASSESS_COMMAND__PRE_DELETE = 7006;
  ASSESS_COMMAND__POST_DELETE = 7007;
  ASSESS_COMMAND__PRE_ENTER_IN_ERROR = 7008;
  ASSESS_COMMAND__POST_ENTER_IN_ERROR = 7009;
  ASSESS_COMMAND__PRE_EXECUTE_ACTION = 7010;
  ASSESS_COMMAND__POST_EXECUTE_ACTION = 7011;
  ASSESS_COMMAND__POST_INSERTED_INTO_NOTE = 7014;
  ASSESS_COMMAND__AVAILABLE_ACTIONS = 7015;
  ASSESS__CONDITION__POST_SEARCH = 7012;
  ASSESS__CONDITION__PRE_SEARCH = 7013;

  CANCEL_PRESCRIPTION_COMMAND__PRE_ORIGINATE = 8000;
  CANCEL_PRESCRIPTION_COMMAND__POST_ORIGINATE = 8001;
  CANCEL_PRESCRIPTION_COMMAND__PRE_UPDATE = 8002;
  CANCEL_PRESCRIPTION_COMMAND__POST_UPDATE = 8003;
  CANCEL_PRESCRIPTION_COMMAND__PRE_COMMIT = 8004;
  CANCEL_PRESCRIPTION_COMMAND__POST_COMMIT = 8005;
  CANCEL_PRESCRIPTION_COMMAND__PRE_DELETE = 8006;
  CANCEL_PRESCRIPTION_COMMAND__POST_DELETE = 8007;
  CANCEL_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR = 8008;
  CANCEL_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR = 8009;
  CANCEL_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION = 8010;
  CANCEL_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION = 8011;
  CANCEL_PRESCRIPTION_COMMAND__POST_INSERTED_INTO_NOTE = 8014;
  CANCEL_PRESCRIPTION_COMMAND__AVAILABLE_ACTIONS = 8015;
  CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__PRE_SEARCH = 8012;
  CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__POST_SEARCH = 8013;

  CHART_SECTION_REVIEW_COMMAND__PRE_ORIGINATE = 9000;
  CHART_SECTION_REVIEW_COMMAND__POST_ORIGINATE = 9001;
  CHART_SECTION_REVIEW_COMMAND__PRE_ENTER_IN_ERROR = 9002;
  CHART_SECTION_REVIEW_COMMAND__POST_ENTER_IN_ERROR = 9003;
  CHART_SECTION_REVIEW_COMMAND__PRE_EXECUTE_ACTION = 9004;
  CHART_SECTION_REVIEW_COMMAND__POST_EXECUTE_ACTION = 9005;
  CHART_SECTION_REVIEW_COMMAND__AVAILABLE_ACTIONS = 9006;


  CLIPBOARD_COMMAND__PRE_ORIGINATE = 53000;
  CLIPBOARD_COMMAND__POST_ORIGINATE = 53001;
  CLIPBOARD_COMMAND__PRE_UPDATE = 53002;
  CLIPBOARD_COMMAND__POST_UPDATE = 53003;
  CLIPBOARD_COMMAND__PRE_COMMIT = 53004;
  CLIPBOARD_COMMAND__POST_COMMIT = 53005;
  CLIPBOARD_COMMAND__PRE_DELETE = 53006;
  CLIPBOARD_COMMAND__POST_DELETE = 53007;
  CLIPBOARD_COMMAND__PRE_ENTER_IN_ERROR = 53008;
  CLIPBOARD_COMMAND__POST_ENTER_IN_ERROR = 54009;
  CLIPBOARD_COMMAND__PRE_EXECUTE_ACTION = 55010;
  CLIPBOARD_COMMAND__POST_EXECUTE_ACTION = 56011;
  CLIPBOARD_COMMAND__POST_INSERTED_INTO_NOTE = 56012;
  CLIPBOARD_COMMAND__AVAILABLE_ACTIONS = 56013;


  CLOSE_GOAL_COMMAND__PRE_ORIGINATE = 10000;
  CLOSE_GOAL_COMMAND__POST_ORIGINATE = 10001;
  CLOSE_GOAL_COMMAND__PRE_UPDATE = 10002;
  CLOSE_GOAL_COMMAND__POST_UPDATE = 10003;
  CLOSE_GOAL_COMMAND__PRE_COMMIT = 10004;
  CLOSE_GOAL_COMMAND__POST_COMMIT = 10005;
  CLOSE_GOAL_COMMAND__PRE_DELETE = 10006;
  CLOSE_GOAL_COMMAND__POST_DELETE = 10007;
  CLOSE_GOAL_COMMAND__PRE_ENTER_IN_ERROR = 10008;
  CLOSE_GOAL_COMMAND__POST_ENTER_IN_ERROR = 10009;
  CLOSE_GOAL_COMMAND__PRE_EXECUTE_ACTION = 10010;
  CLOSE_GOAL_COMMAND__POST_EXECUTE_ACTION = 10011;
  CLOSE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE = 10014;
  CLOSE_GOAL_COMMAND__AVAILABLE_ACTIONS = 10015;
  CLOSE_GOAL__GOAL_ID__PRE_SEARCH = 10012;
  CLOSE_GOAL__GOAL_ID__POST_SEARCH = 10013;

  // DENY_CHANGE_COMMAND__PRE_ORIGINATE = 11000;
  // DENY_CHANGE_COMMAND__POST_ORIGINATE = 11001;
  // DENY_CHANGE_COMMAND__PRE_UPDATE = 11002;
  // DENY_CHANGE_COMMAND__POST_UPDATE = 11003;
  // DENY_CHANGE_COMMAND__PRE_COMMIT = 11004;
  // DENY_CHANGE_COMMAND__POST_COMMIT = 11005;
  // DENY_CHANGE_COMMAND__PRE_DELETE = 11006;
  // DENY_CHANGE_COMMAND__POST_DELETE = 11007;
  // DENY_CHANGE_COMMAND__PRE_ENTER_IN_ERROR = 11008;
  // DENY_CHANGE_COMMAND__POST_ENTER_IN_ERROR = 11009;
  // DENY_CHANGE_COMMAND__PRE_EXECUTE_ACTION = 11010;
  // DENY_CHANGE_COMMAND__POST_EXECUTE_ACTION = 11011;

  // DENY_REFILL_COMMAND__PRE_ORIGINATE = 12000;
  // DENY_REFILL_COMMAND__POST_ORIGINATE = 12001;
  // DENY_REFILL_COMMAND__PRE_UPDATE = 12002;
  // DENY_REFILL_COMMAND__POST_UPDATE = 12003;
  // DENY_REFILL_COMMAND__PRE_COMMIT = 12004;
  // DENY_REFILL_COMMAND__POST_COMMIT = 12005;
  // DENY_REFILL_COMMAND__PRE_DELETE = 12006;
  // DENY_REFILL_COMMAND__POST_DELETE = 12007;
  // DENY_REFILL_COMMAND__PRE_ENTER_IN_ERROR = 12008;
  // DENY_REFILL_COMMAND__POST_ENTER_IN_ERROR = 12009;
  // DENY_REFILL_COMMAND__PRE_EXECUTE_ACTION = 12010;
  // DENY_REFILL_COMMAND__POST_EXECUTE_ACTION = 12011;

  // DEVICE_COMMAND__PRE_ORIGINATE = 13000;
  // DEVICE_COMMAND__POST_ORIGINATE = 13001;
  // DEVICE_COMMAND__PRE_UPDATE = 13002;
  // DEVICE_COMMAND__POST_UPDATE = 13003;
  // DEVICE_COMMAND__PRE_COMMIT = 13004;
  // DEVICE_COMMAND__POST_COMMIT = 13005;
  // DEVICE_COMMAND__PRE_DELETE = 13006;
  // DEVICE_COMMAND__POST_DELETE = 13007;
  // DEVICE_COMMAND__PRE_ENTER_IN_ERROR = 13008;
  // DEVICE_COMMAND__POST_ENTER_IN_ERROR = 13009;
  // DEVICE_COMMAND__PRE_EXECUTE_ACTION = 13010;
  // DEVICE_COMMAND__POST_EXECUTE_ACTION = 13011;

  DIAGNOSE_COMMAND__PRE_ORIGINATE = 14000;
  DIAGNOSE_COMMAND__POST_ORIGINATE = 14001;
  DIAGNOSE_COMMAND__PRE_UPDATE = 14002;
  DIAGNOSE_COMMAND__POST_UPDATE = 14003;
  DIAGNOSE_COMMAND__PRE_COMMIT = 14004;
  DIAGNOSE_COMMAND__POST_COMMIT = 14005;
  DIAGNOSE_COMMAND__PRE_DELETE = 14006;
  DIAGNOSE_COMMAND__POST_DELETE = 14007;
  DIAGNOSE_COMMAND__PRE_ENTER_IN_ERROR = 14008;
  DIAGNOSE_COMMAND__POST_ENTER_IN_ERROR = 14009;
  DIAGNOSE_COMMAND__PRE_EXECUTE_ACTION = 14010;
  DIAGNOSE_COMMAND__POST_EXECUTE_ACTION = 14011;
  DIAGNOSE_COMMAND__POST_INSERTED_INTO_NOTE = 14014;
  DIAGNOSE_COMMAND__AVAILABLE_ACTIONS = 14015;
  DIAGNOSE__DIAGNOSE__POST_SEARCH = 14012;
  DIAGNOSE__DIAGNOSE__PRE_SEARCH = 14013;

  EDUCATIONAL_MATERIAL_COMMAND__PRE_ORIGINATE = 15000;
  EDUCATIONAL_MATERIAL_COMMAND__POST_ORIGINATE = 15001;
  EDUCATIONAL_MATERIAL_COMMAND__PRE_UPDATE = 15002;
  EDUCATIONAL_MATERIAL_COMMAND__POST_UPDATE = 15003;
  EDUCATIONAL_MATERIAL_COMMAND__PRE_COMMIT = 15004;
  EDUCATIONAL_MATERIAL_COMMAND__POST_COMMIT = 15005;
  EDUCATIONAL_MATERIAL_COMMAND__PRE_DELETE = 15006;
  EDUCATIONAL_MATERIAL_COMMAND__POST_DELETE = 15007;
  EDUCATIONAL_MATERIAL_COMMAND__PRE_ENTER_IN_ERROR = 15008;
  EDUCATIONAL_MATERIAL_COMMAND__POST_ENTER_IN_ERROR = 15009;
  EDUCATIONAL_MATERIAL_COMMAND__PRE_EXECUTE_ACTION = 15010;
  EDUCATIONAL_MATERIAL_COMMAND__POST_EXECUTE_ACTION = 15011;
  EDUCATIONAL_MATERIAL_COMMAND__POST_INSERTED_INTO_NOTE = 15016;
  EDUCATIONAL_MATERIAL_COMMAND__AVAILABLE_ACTIONS = 15017;
  EDUCATIONAL_MATERIAL__TITLE__PRE_SEARCH = 15012;
  EDUCATIONAL_MATERIAL__TITLE__POST_SEARCH = 15013;
  EDUCATIONAL_MATERIAL__LANGUAGE__PRE_SEARCH = 15014;
  EDUCATIONAL_MATERIAL__LANGUAGE__POST_SEARCH = 15015;


  FAMILY_HISTORY_COMMAND__PRE_ORIGINATE = 16000;
  FAMILY_HISTORY_COMMAND__POST_ORIGINATE = 16001;
  FAMILY_HISTORY_COMMAND__PRE_UPDATE = 16002;
  FAMILY_HISTORY_COMMAND__POST_UPDATE = 16003;
  FAMILY_HISTORY_COMMAND__PRE_COMMIT = 16004;
  FAMILY_HISTORY_COMMAND__POST_COMMIT = 16005;
  FAMILY_HISTORY_COMMAND__PRE_DELETE = 16006;
  FAMILY_HISTORY_COMMAND__POST_DELETE = 16007;
  FAMILY_HISTORY_COMMAND__PRE_ENTER_IN_ERROR = 16008;
  FAMILY_HISTORY_COMMAND__POST_ENTER_IN_ERROR = 16009;
  FAMILY_HISTORY_COMMAND__PRE_EXECUTE_ACTION = 16010;
  FAMILY_HISTORY_COMMAND__POST_EXECUTE_ACTION = 16011;
  FAMILY_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE = 16016;
  FAMILY_HISTORY_COMMAND__AVAILABLE_ACTIONS = 16017;
  FAMILY_HISTORY__FAMILY_HISTORY__PRE_SEARCH = 16012;
  FAMILY_HISTORY__FAMILY_HISTORY__POST_SEARCH = 16013;
  FAMILY_HISTORY__RELATIVE__PRE_SEARCH = 16014;
  FAMILY_HISTORY__RELATIVE__POST_SEARCH = 16015;


  FOLLOW_UP_COMMAND__PRE_ORIGINATE = 17000;
  FOLLOW_UP_COMMAND__POST_ORIGINATE = 17001;
  FOLLOW_UP_COMMAND__PRE_UPDATE = 17002;
  FOLLOW_UP_COMMAND__POST_UPDATE = 17003;
  FOLLOW_UP_COMMAND__PRE_COMMIT = 17004;
  FOLLOW_UP_COMMAND__POST_COMMIT = 17005;
  FOLLOW_UP_COMMAND__PRE_DELETE = 17006;
  FOLLOW_UP_COMMAND__POST_DELETE = 17007;
  FOLLOW_UP_COMMAND__PRE_ENTER_IN_ERROR = 17008;
  FOLLOW_UP_COMMAND__POST_ENTER_IN_ERROR = 17009;
  FOLLOW_UP_COMMAND__PRE_EXECUTE_ACTION = 17010;
  FOLLOW_UP_COMMAND__POST_EXECUTE_ACTION = 17011;
  FOLLOW_UP_COMMAND__POST_INSERTED_INTO_NOTE = 17016;
  FOLLOW_UP_COMMAND__AVAILABLE_ACTIONS = 17017;
  FOLLOW_UP__CODING__PRE_SEARCH = 17012;
  FOLLOW_UP__CODING__POST_SEARCH = 17013;
  FOLLOW_UP__NOTE_TYPE__PRE_SEARCH = 17014;
  FOLLOW_UP__NOTE_TYPE__POST_SEARCH = 17015;

  GOAL_COMMAND__PRE_ORIGINATE = 18000;
  GOAL_COMMAND__POST_ORIGINATE = 18001;
  GOAL_COMMAND__PRE_UPDATE = 18002;
  GOAL_COMMAND__POST_UPDATE = 18003;
  GOAL_COMMAND__PRE_COMMIT = 18004;
  GOAL_COMMAND__POST_COMMIT = 18005;
  GOAL_COMMAND__PRE_DELETE = 18006;
  GOAL_COMMAND__POST_DELETE = 18007;
  GOAL_COMMAND__PRE_ENTER_IN_ERROR = 18008;
  GOAL_COMMAND__POST_ENTER_IN_ERROR = 18009;
  GOAL_COMMAND__PRE_EXECUTE_ACTION = 18010;
  GOAL_COMMAND__POST_EXECUTE_ACTION = 18011;
  GOAL_COMMAND__POST_INSERTED_INTO_NOTE = 18014;
  GOAL_COMMAND__AVAILABLE_ACTIONS = 18015;

  HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ORIGINATE = 19000;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ORIGINATE = 19001;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_UPDATE = 19002;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_UPDATE = 19003;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_COMMIT = 19004;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_COMMIT = 19005;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_DELETE = 19006;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_DELETE = 19007;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ENTER_IN_ERROR = 19008;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ENTER_IN_ERROR = 19009;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_EXECUTE_ACTION = 19010;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_EXECUTE_ACTION = 19011;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_INSERTED_INTO_NOTE = 19012;
  HISTORY_OF_PRESENT_ILLNESS_COMMAND__AVAILABLE_ACTIONS = 19013;

  IMAGING_ORDER_COMMAND__PRE_ORIGINATE = 20000;
  IMAGING_ORDER_COMMAND__POST_ORIGINATE = 20001;
  IMAGING_ORDER_COMMAND__PRE_UPDATE = 20002;
  IMAGING_ORDER_COMMAND__POST_UPDATE = 20003;
  IMAGING_ORDER_COMMAND__PRE_COMMIT = 20004;
  IMAGING_ORDER_COMMAND__POST_COMMIT = 20005;
  IMAGING_ORDER_COMMAND__PRE_DELETE = 20006;
  IMAGING_ORDER_COMMAND__POST_DELETE = 20007;
  IMAGING_ORDER_COMMAND__PRE_ENTER_IN_ERROR = 20008;
  IMAGING_ORDER_COMMAND__POST_ENTER_IN_ERROR = 20009;
  IMAGING_ORDER_COMMAND__PRE_EXECUTE_ACTION = 20010;
  IMAGING_ORDER_COMMAND__POST_EXECUTE_ACTION = 20011;
  IMAGING_ORDER_COMMAND__POST_INSERTED_INTO_NOTE = 20020;
  IMAGING_ORDER_COMMAND__AVAILABLE_ACTIONS = 20021;
  IMAGING_ORDER__IMAGE__PRE_SEARCH = 20012;
  IMAGING_ORDER__IMAGE__POST_SEARCH = 20013;
  IMAGING_ORDER__INDICATIONS__PRE_SEARCH = 20014;
  IMAGING_ORDER__INDICATIONS__POST_SEARCH = 20015;
  IMAGING_ORDER__IMAGING_CENTER__PRE_SEARCH = 20016;
  IMAGING_ORDER__IMAGING_CENTER__POST_SEARCH = 20017;
  IMAGING_ORDER__ORDERING_PROVIDER__PRE_SEARCH = 20018;
  IMAGING_ORDER__ORDERING_PROVIDER__POST_SEARCH = 20019;

  // IMAGING_REVIEW_COMMAND__PRE_ORIGINATE = 21000;
  // IMAGING_REVIEW_COMMAND__POST_ORIGINATE = 21001;
  // IMAGING_REVIEW_COMMAND__PRE_UPDATE = 21002;
  // IMAGING_REVIEW_COMMAND__POST_UPDATE = 21003;
  // IMAGING_REVIEW_COMMAND__PRE_COMMIT = 21004;
  // IMAGING_REVIEW_COMMAND__POST_COMMIT = 21005;
  // IMAGING_REVIEW_COMMAND__PRE_DELETE = 21006;
  // IMAGING_REVIEW_COMMAND__POST_DELETE = 21007;
  // IMAGING_REVIEW_COMMAND__PRE_ENTER_IN_ERROR = 21008;
  // IMAGING_REVIEW_COMMAND__POST_ENTER_IN_ERROR = 21009;
  // IMAGING_REVIEW_COMMAND__PRE_EXECUTE_ACTION = 21010;
  // IMAGING_REVIEW_COMMAND__POST_EXECUTE_ACTION = 21011;

  IMMUNIZATION_STATEMENT_COMMAND__PRE_ORIGINATE = 22000;
  IMMUNIZATION_STATEMENT_COMMAND__POST_ORIGINATE = 22001;
  IMMUNIZATION_STATEMENT_COMMAND__PRE_UPDATE = 22002;
  IMMUNIZATION_STATEMENT_COMMAND__POST_UPDATE = 22003;
  IMMUNIZATION_STATEMENT_COMMAND__PRE_COMMIT = 22004;
  IMMUNIZATION_STATEMENT_COMMAND__POST_COMMIT = 22005;
  IMMUNIZATION_STATEMENT_COMMAND__PRE_DELETE = 22006;
  IMMUNIZATION_STATEMENT_COMMAND__POST_DELETE = 22007;
  IMMUNIZATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR = 22008;
  IMMUNIZATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR = 22009;
  IMMUNIZATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION = 22010;
  IMMUNIZATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION = 22011;
  IMMUNIZATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE = 22014;
  IMMUNIZATION_STATEMENT_COMMAND__AVAILABLE_ACTIONS = 22015;
  IMMUNIZATION_STATEMENT__STATEMENT__PRE_SEARCH = 22012;
  IMMUNIZATION_STATEMENT__STATEMENT__POST_SEARCH = 22013;


  IMMUNIZE_COMMAND__PRE_ORIGINATE = 23000;
  IMMUNIZE_COMMAND__POST_ORIGINATE = 23001;
  IMMUNIZE_COMMAND__PRE_UPDATE = 23002;
  IMMUNIZE_COMMAND__POST_UPDATE = 23003;
  IMMUNIZE_COMMAND__PRE_COMMIT = 23004;
  IMMUNIZE_COMMAND__POST_COMMIT = 23005;
  IMMUNIZE_COMMAND__PRE_DELETE = 23006;
  IMMUNIZE_COMMAND__POST_DELETE = 23007;
  IMMUNIZE_COMMAND__PRE_ENTER_IN_ERROR = 23008;
  IMMUNIZE_COMMAND__POST_ENTER_IN_ERROR = 23009;
  IMMUNIZE_COMMAND__PRE_EXECUTE_ACTION = 23010;
  IMMUNIZE_COMMAND__POST_EXECUTE_ACTION = 23011;
  IMMUNIZE_COMMAND__POST_INSERTED_INTO_NOTE = 23018;
  IMMUNIZE_COMMAND__AVAILABLE_ACTIONS = 23019;
  IMMUNIZE__CODING__PRE_SEARCH = 23012;
  IMMUNIZE__CODING__POST_SEARCH = 23013;
  IMMUNIZE__LOT_NUMBER__PRE_SEARCH = 23014;
  IMMUNIZE__LOT_NUMBER__POST_SEARCH = 23015;
  IMMUNIZE__GIVEN_BY__PRE_SEARCH = 23016;
  IMMUNIZE__GIVEN_BY__POST_SEARCH = 23017;

  INSTRUCT_COMMAND__PRE_ORIGINATE = 24000;
  INSTRUCT_COMMAND__POST_ORIGINATE = 24001;
  INSTRUCT_COMMAND__PRE_UPDATE = 24002;
  INSTRUCT_COMMAND__POST_UPDATE = 24003;
  INSTRUCT_COMMAND__PRE_COMMIT = 24004;
  INSTRUCT_COMMAND__POST_COMMIT = 24005;
  INSTRUCT_COMMAND__PRE_DELETE = 24006;
  INSTRUCT_COMMAND__POST_DELETE = 24007;
  INSTRUCT_COMMAND__PRE_ENTER_IN_ERROR = 24008;
  INSTRUCT_COMMAND__POST_ENTER_IN_ERROR = 24009;
  INSTRUCT_COMMAND__PRE_EXECUTE_ACTION = 24010;
  INSTRUCT_COMMAND__POST_EXECUTE_ACTION = 24011;
  INSTRUCT_COMMAND__POST_INSERTED_INTO_NOTE = 24014;
  INSTRUCT_COMMAND__AVAILABLE_ACTIONS = 24015;
  INSTRUCT__INSTRUCT__PRE_SEARCH = 24012;
  INSTRUCT__INSTRUCT__POST_SEARCH = 24013;

  LAB_ORDER_COMMAND__PRE_ORIGINATE = 25000;
  LAB_ORDER_COMMAND__POST_ORIGINATE = 25001;
  LAB_ORDER_COMMAND__PRE_UPDATE = 25002;
  LAB_ORDER_COMMAND__POST_UPDATE = 25003;
  LAB_ORDER_COMMAND__PRE_COMMIT = 25004;
  LAB_ORDER_COMMAND__POST_COMMIT = 25005;
  LAB_ORDER_COMMAND__PRE_DELETE = 25006;
  LAB_ORDER_COMMAND__POST_DELETE = 25007;
  LAB_ORDER_COMMAND__PRE_ENTER_IN_ERROR = 25008;
  LAB_ORDER_COMMAND__POST_ENTER_IN_ERROR = 25009;
  LAB_ORDER_COMMAND__PRE_EXECUTE_ACTION = 25010;
  LAB_ORDER_COMMAND__POST_EXECUTE_ACTION = 25011;
  LAB_ORDER_COMMAND__POST_INSERTED_INTO_NOTE = 25020;
  LAB_ORDER_COMMAND__AVAILABLE_ACTIONS = 25021;
  LAB_ORDER__LAB_PARTNER__PRE_SEARCH = 25012;
  LAB_ORDER__LAB_PARTNER__POST_SEARCH = 25013;
  LAB_ORDER__TESTS__PRE_SEARCH = 25014;
  LAB_ORDER__TESTS__POST_SEARCH = 25015;
  LAB_ORDER__ORDERING_PROVIDER__PRE_SEARCH = 25016;
  LAB_ORDER__ORDERING_PROVIDER__POST_SEARCH = 25017;
  LAB_ORDER__DIAGNOSIS__PRE_SEARCH = 25018;
  LAB_ORDER__DIAGNOSIS__POST_SEARCH = 25019;

  // LAB_REVIEW_COMMAND__PRE_ORIGINATE = 26000;
  // LAB_REVIEW_COMMAND__POST_ORIGINATE = 26001;
  // LAB_REVIEW_COMMAND__PRE_UPDATE = 26002;
  // LAB_REVIEW_COMMAND__POST_UPDATE = 26003;
  // LAB_REVIEW_COMMAND__PRE_COMMIT = 26004;
  // LAB_REVIEW_COMMAND__POST_COMMIT = 26005;
  // LAB_REVIEW_COMMAND__PRE_DELETE = 26006;
  // LAB_REVIEW_COMMAND__POST_DELETE = 26007;
  // LAB_REVIEW_COMMAND__PRE_ENTER_IN_ERROR = 26008;
  // LAB_REVIEW_COMMAND__POST_ENTER_IN_ERROR = 26009;
  // LAB_REVIEW_COMMAND__PRE_EXECUTE_ACTION = 26010;
  // LAB_REVIEW_COMMAND__POST_EXECUTE_ACTION = 26011;

  MEDICAL_HISTORY_COMMAND__PRE_ORIGINATE = 27000;
  MEDICAL_HISTORY_COMMAND__POST_ORIGINATE = 27001;
  MEDICAL_HISTORY_COMMAND__PRE_UPDATE = 27002;
  MEDICAL_HISTORY_COMMAND__POST_UPDATE = 27003;
  MEDICAL_HISTORY_COMMAND__PRE_COMMIT = 27004;
  MEDICAL_HISTORY_COMMAND__POST_COMMIT = 27005;
  MEDICAL_HISTORY_COMMAND__PRE_DELETE = 27006;
  MEDICAL_HISTORY_COMMAND__POST_DELETE = 27007;
  MEDICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR = 27008;
  MEDICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR = 27009;
  MEDICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION = 27010;
  MEDICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION = 27011;
  MEDICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE = 27018;
  MEDICAL_HISTORY_COMMAND__AVAILABLE_ACTIONS = 27019;
  MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__PRE_SEARCH = 27012;
  MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__POST_SEARCH = 27013;
  MEDICAL_HISTORY__APPROXIMATE_START_DATE__PRE_SEARCH = 27014;
  MEDICAL_HISTORY__APPROXIMATE_START_DATE__POST_SEARCH = 27015;
  MEDICAL_HISTORY__APPROXIMATE_END_DATE__PRE_SEARCH = 27016;
  MEDICAL_HISTORY__APPROXIMATE_END_DATE__POST_SEARCH = 27017;

  MEDICATION_STATEMENT_COMMAND__PRE_ORIGINATE = 28000;
  MEDICATION_STATEMENT_COMMAND__POST_ORIGINATE = 28001;
  MEDICATION_STATEMENT_COMMAND__PRE_UPDATE = 28002;
  MEDICATION_STATEMENT_COMMAND__POST_UPDATE = 28003;
  MEDICATION_STATEMENT_COMMAND__PRE_COMMIT = 28004;
  MEDICATION_STATEMENT_COMMAND__POST_COMMIT = 28005;
  MEDICATION_STATEMENT_COMMAND__PRE_DELETE = 28006;
  MEDICATION_STATEMENT_COMMAND__POST_DELETE = 28007;
  MEDICATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR = 28008;
  MEDICATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR = 28009;
  MEDICATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION = 28010;
  MEDICATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION = 28011;
  MEDICATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE = 28012;
  MEDICATION_STATEMENT_COMMAND__AVAILABLE_ACTIONS = 28013;

  PERFORM_COMMAND__PRE_ORIGINATE = 29000;
  PERFORM_COMMAND__POST_ORIGINATE = 29001;
  PERFORM_COMMAND__PRE_UPDATE = 29002;
  PERFORM_COMMAND__POST_UPDATE = 29003;
  PERFORM_COMMAND__PRE_COMMIT = 29004;
  PERFORM_COMMAND__POST_COMMIT = 29005;
  PERFORM_COMMAND__PRE_DELETE = 29006;
  PERFORM_COMMAND__POST_DELETE = 29007;
  PERFORM_COMMAND__PRE_ENTER_IN_ERROR = 29008;
  PERFORM_COMMAND__POST_ENTER_IN_ERROR = 29009;
  PERFORM_COMMAND__PRE_EXECUTE_ACTION = 29010;
  PERFORM_COMMAND__POST_EXECUTE_ACTION = 29011;
  PERFORM_COMMAND__POST_INSERTED_INTO_NOTE = 29014;
  PERFORM_COMMAND__AVAILABLE_ACTIONS = 29015;
  PERFORM__PERFORM__PRE_SEARCH = 29012;
  PERFORM__PERFORM__POST_SEARCH = 29013;

  PHYSICAL_EXAM_COMMAND__PRE_ORIGINATE = 30000;
  PHYSICAL_EXAM_COMMAND__POST_ORIGINATE = 30001;
  PHYSICAL_EXAM_COMMAND__PRE_UPDATE = 30002;
  PHYSICAL_EXAM_COMMAND__POST_UPDATE = 30003;
  PHYSICAL_EXAM_COMMAND__PRE_COMMIT = 30004;
  PHYSICAL_EXAM_COMMAND__POST_COMMIT = 30005;
  PHYSICAL_EXAM_COMMAND__PRE_DELETE = 30006;
  PHYSICAL_EXAM_COMMAND__POST_DELETE = 30007;
  PHYSICAL_EXAM_COMMAND__PRE_ENTER_IN_ERROR = 30008;
  PHYSICAL_EXAM_COMMAND__POST_ENTER_IN_ERROR = 30009;
  PHYSICAL_EXAM_COMMAND__PRE_EXECUTE_ACTION = 30010;
  PHYSICAL_EXAM_COMMAND__POST_EXECUTE_ACTION = 30011;
  PHYSICAL_EXAM_COMMAND__POST_INSERTED_INTO_NOTE = 30014;
  PHYSICAL_EXAM_COMMAND__AVAILABLE_ACTIONS = 30015;
  PHYSICAL_EXAM__QUESTIONNAIRE__PRE_SEARCH = 30012;
  PHYSICAL_EXAM__QUESTIONNAIRE__POST_SEARCH = 30013;

  PLAN_COMMAND__PRE_ORIGINATE = 31000;
  PLAN_COMMAND__POST_ORIGINATE = 31001;
  PLAN_COMMAND__PRE_UPDATE = 31002;
  PLAN_COMMAND__POST_UPDATE = 31003;
  PLAN_COMMAND__PRE_COMMIT = 31004;
  PLAN_COMMAND__POST_COMMIT = 31005;
  PLAN_COMMAND__PRE_DELETE = 31006;
  PLAN_COMMAND__POST_DELETE = 31007;
  PLAN_COMMAND__PRE_ENTER_IN_ERROR = 31008;
  PLAN_COMMAND__POST_ENTER_IN_ERROR = 31009;
  PLAN_COMMAND__PRE_EXECUTE_ACTION = 31010;
  PLAN_COMMAND__POST_EXECUTE_ACTION = 31011;
  PLAN_COMMAND__POST_INSERTED_INTO_NOTE = 31012;
  PLAN_COMMAND__AVAILABLE_ACTIONS = 31013;

  // POC_LAB_TEST_COMMAND__PRE_ORIGINATE = 32000;
  // POC_LAB_TEST_COMMAND__POST_ORIGINATE = 32001;
  // POC_LAB_TEST_COMMAND__PRE_UPDATE = 32002;
  // POC_LAB_TEST_COMMAND__POST_UPDATE = 32003;
  // POC_LAB_TEST_COMMAND__PRE_COMMIT = 32004;
  // POC_LAB_TEST_COMMAND__POST_COMMIT = 32005;
  // POC_LAB_TEST_COMMAND__PRE_DELETE = 32006;
  // POC_LAB_TEST_COMMAND__POST_DELETE = 32007;
  // POC_LAB_TEST_COMMAND__PRE_ENTER_IN_ERROR = 32008;
  // POC_LAB_TEST_COMMAND__POST_ENTER_IN_ERROR = 32009;
  // POC_LAB_TEST_COMMAND__PRE_EXECUTE_ACTION = 32010;
  // POC_LAB_TEST_COMMAND__POST_EXECUTE_ACTION = 32011;

  PRESCRIBE_COMMAND__PRE_ORIGINATE = 33000;
  PRESCRIBE_COMMAND__POST_ORIGINATE = 33001;
  PRESCRIBE_COMMAND__PRE_UPDATE = 33002;
  PRESCRIBE_COMMAND__POST_UPDATE = 33003;
  PRESCRIBE_COMMAND__PRE_COMMIT = 33004;
  PRESCRIBE_COMMAND__POST_COMMIT = 33005;
  PRESCRIBE_COMMAND__PRE_DELETE = 33006;
  PRESCRIBE_COMMAND__POST_DELETE = 33007;
  PRESCRIBE_COMMAND__PRE_ENTER_IN_ERROR = 33008;
  PRESCRIBE_COMMAND__POST_ENTER_IN_ERROR = 33009;
  PRESCRIBE_COMMAND__PRE_EXECUTE_ACTION = 33010;
  PRESCRIBE_COMMAND__POST_EXECUTE_ACTION = 33011;
  PRESCRIBE_COMMAND__POST_INSERTED_INTO_NOTE = 33018;
  PRESCRIBE_COMMAND__AVAILABLE_ACTIONS = 33021;
  PRESCRIBE__PRESCRIBE__POST_SEARCH = 33012;
  PRESCRIBE__PRESCRIBE__PRE_SEARCH = 33013;
  PRESCRIBE__INDICATIONS__PRE_SEARCH = 33014;
  PRESCRIBE__INDICATIONS__POST_SEARCH = 33015;
  PRESCRIBE__PHARMACY__PRE_SEARCH = 33016;
  PRESCRIBE__PHARMACY__POST_SEARCH = 33017;
  PRESCRIBE__SUPERVISING_PROVIDER__POST_SEARCH = 33019;
  PRESCRIBE__SUPERVISING_PROVIDER__PRE_SEARCH = 33020;
  PRESCRIBE__PRESCRIBER__PRE_SEARCH = 33023;
  PRESCRIBE__PRESCRIBER__POST_SEARCH = 33024;

  QUESTIONNAIRE_COMMAND__PRE_ORIGINATE = 34000;
  QUESTIONNAIRE_COMMAND__POST_ORIGINATE = 34001;
  QUESTIONNAIRE_COMMAND__PRE_UPDATE = 34002;
  QUESTIONNAIRE_COMMAND__POST_UPDATE = 34003;
  QUESTIONNAIRE_COMMAND__PRE_COMMIT = 34004;
  QUESTIONNAIRE_COMMAND__POST_COMMIT = 34005;
  QUESTIONNAIRE_COMMAND__PRE_DELETE = 34006;
  QUESTIONNAIRE_COMMAND__POST_DELETE = 34007;
  QUESTIONNAIRE_COMMAND__PRE_ENTER_IN_ERROR = 34008;
  QUESTIONNAIRE_COMMAND__POST_ENTER_IN_ERROR = 34009;
  QUESTIONNAIRE_COMMAND__PRE_EXECUTE_ACTION = 34010;
  QUESTIONNAIRE_COMMAND__POST_EXECUTE_ACTION = 34011;
  QUESTIONNAIRE_COMMAND__POST_INSERTED_INTO_NOTE = 34014;
  QUESTIONNAIRE_COMMAND__AVAILABLE_ACTIONS = 34015;
  QUESTIONNAIRE__QUESTIONNAIRE__POST_SEARCH = 34012;
  QUESTIONNAIRE__QUESTIONNAIRE__PRE_SEARCH = 34013;

  REASON_FOR_VISIT_COMMAND__PRE_ORIGINATE = 35000;
  REASON_FOR_VISIT_COMMAND__POST_ORIGINATE = 35001;
  REASON_FOR_VISIT_COMMAND__PRE_UPDATE = 35002;
  REASON_FOR_VISIT_COMMAND__POST_UPDATE = 35003;
  REASON_FOR_VISIT_COMMAND__PRE_COMMIT = 35004;
  REASON_FOR_VISIT_COMMAND__POST_COMMIT = 35005;
  REASON_FOR_VISIT_COMMAND__PRE_DELETE = 35006;
  REASON_FOR_VISIT_COMMAND__POST_DELETE = 35007;
  REASON_FOR_VISIT_COMMAND__PRE_ENTER_IN_ERROR = 35008;
  REASON_FOR_VISIT_COMMAND__POST_ENTER_IN_ERROR = 35009;
  REASON_FOR_VISIT_COMMAND__PRE_EXECUTE_ACTION = 35010;
  REASON_FOR_VISIT_COMMAND__POST_EXECUTE_ACTION = 35011;
  REASON_FOR_VISIT_COMMAND__POST_INSERTED_INTO_NOTE = 35014;
  REASON_FOR_VISIT_COMMAND__AVAILABLE_ACTIONS = 35015;
  REASON_FOR_VISIT__CODING__POST_SEARCH = 35012;
  REASON_FOR_VISIT__CODING__PRE_SEARCH = 35013;

  REFER_COMMAND__PRE_ORIGINATE = 36000;
  REFER_COMMAND__POST_ORIGINATE = 36001;
  REFER_COMMAND__PRE_UPDATE = 36002;
  REFER_COMMAND__POST_UPDATE = 36003;
  REFER_COMMAND__PRE_COMMIT = 36004;
  REFER_COMMAND__POST_COMMIT = 36005;
  REFER_COMMAND__PRE_DELETE = 36006;
  REFER_COMMAND__POST_DELETE = 36007;
  REFER_COMMAND__PRE_ENTER_IN_ERROR = 36008;
  REFER_COMMAND__POST_ENTER_IN_ERROR = 36009;
  REFER_COMMAND__PRE_EXECUTE_ACTION = 36010;
  REFER_COMMAND__POST_EXECUTE_ACTION = 36011;
  REFER_COMMAND__POST_INSERTED_INTO_NOTE = 36020;
  REFER_COMMAND__AVAILABLE_ACTIONS = 36021;
  REFER__REFER_TO__POST_SEARCH = 36012;
  REFER__REFER_TO__PRE_SEARCH = 36013;
  REFER__INDICATIONS__POST_SEARCH = 36014;
  REFER__INDICATIONS__PRE_SEARCH = 36015;
  REFER__DOCUMENTS_TO_INCLUDE__POST_SEARCH = 36016;
  REFER__DOCUMENTS_TO_INCLUDE__PRE_SEARCH = 36017;
  REFER__LINKED_ITEMS__POST_SEARCH = 36018;
  REFER__LINKED_ITEMS_INCLUDE__PRE_SEARCH = 36019;

  // REFERENCE_COMMAND__PRE_ORIGINATE = 37000;
  // REFERENCE_COMMAND__POST_ORIGINATE = 37001;
  // REFERENCE_COMMAND__PRE_UPDATE = 37002;
  // REFERENCE_COMMAND__POST_UPDATE = 37003;
  // REFERENCE_COMMAND__PRE_COMMIT = 37004;
  // REFERENCE_COMMAND__POST_COMMIT = 37005;
  // REFERENCE_COMMAND__PRE_DELETE = 37006;
  // REFERENCE_COMMAND__POST_DELETE = 37007;
  // REFERENCE_COMMAND__PRE_ENTER_IN_ERROR = 37008;
  // REFERENCE_COMMAND__POST_ENTER_IN_ERROR = 37009;
  // REFERENCE_COMMAND__PRE_EXECUTE_ACTION = 37010;
  // REFERENCE_COMMAND__POST_EXECUTE_ACTION = 37011;

  // REFERRAL_REVIEW_COMMAND__PRE_ORIGINATE = 38000;
  // REFERRAL_REVIEW_COMMAND__POST_ORIGINATE = 38001;
  // REFERRAL_REVIEW_COMMAND__PRE_UPDATE = 38002;
  // REFERRAL_REVIEW_COMMAND__POST_UPDATE = 38003;
  // REFERRAL_REVIEW_COMMAND__PRE_COMMIT = 38004;
  // REFERRAL_REVIEW_COMMAND__POST_COMMIT = 38005;
  // REFERRAL_REVIEW_COMMAND__PRE_DELETE = 38006;
  // REFERRAL_REVIEW_COMMAND__POST_DELETE = 38007;
  // REFERRAL_REVIEW_COMMAND__PRE_ENTER_IN_ERROR = 38008;
  // REFERRAL_REVIEW_COMMAND__POST_ENTER_IN_ERROR = 38009;
  // REFERRAL_REVIEW_COMMAND__PRE_EXECUTE_ACTION = 38010;
  // REFERRAL_REVIEW_COMMAND__POST_EXECUTE_ACTION = 38011;

  REFILL_COMMAND__PRE_ORIGINATE = 39000;
  REFILL_COMMAND__POST_ORIGINATE = 39001;
  REFILL_COMMAND__PRE_UPDATE = 39002;
  REFILL_COMMAND__POST_UPDATE = 39003;
  REFILL_COMMAND__PRE_COMMIT = 39004;
  REFILL_COMMAND__POST_COMMIT = 39005;
  REFILL_COMMAND__PRE_DELETE = 39006;
  REFILL_COMMAND__POST_DELETE = 39007;
  REFILL_COMMAND__PRE_ENTER_IN_ERROR = 39008;
  REFILL_COMMAND__POST_ENTER_IN_ERROR = 39009;
  REFILL_COMMAND__PRE_EXECUTE_ACTION = 39010;
  REFILL_COMMAND__POST_EXECUTE_ACTION = 39011;
  REFILL_COMMAND__POST_INSERTED_INTO_NOTE = 39018;
  REFILL_COMMAND__AVAILABLE_ACTIONS = 39021;
  REFILL__PRESCRIBE__PRE_SEARCH = 39012;
  REFILL__PRESCRIBE__POST_SEARCH = 39013;
  REFILL__INDICATIONS__PRE_SEARCH = 39014;
  REFILL__INDICATIONS__POST_SEARCH = 39015;
  REFILL__PHARMACY__PRE_SEARCH = 39016;
  REFILL__PHARMACY__POST_SEARCH = 39017;
  REFILL__SUPERVISING_PROVIDER__PRE_SEARCH = 39019;
  REFILL__SUPERVISING_PROVIDER__POST_SEARCH = 39020;
  REFILL__PRESCRIBER__PRE_SEARCH = 39023;
  REFILL__PRESCRIBER__POST_SEARCH = 39024;

  REMOVE_ALLERGY_COMMAND__PRE_ORIGINATE = 40000;
  REMOVE_ALLERGY_COMMAND__POST_ORIGINATE = 40001;
  REMOVE_ALLERGY_COMMAND__PRE_UPDATE = 40002;
  REMOVE_ALLERGY_COMMAND__POST_UPDATE = 40003;
  REMOVE_ALLERGY_COMMAND__PRE_COMMIT = 40004;
  REMOVE_ALLERGY_COMMAND__POST_COMMIT = 40005;
  REMOVE_ALLERGY_COMMAND__PRE_DELETE = 40006;
  REMOVE_ALLERGY_COMMAND__POST_DELETE = 40007;
  REMOVE_ALLERGY_COMMAND__PRE_ENTER_IN_ERROR = 40008;
  REMOVE_ALLERGY_COMMAND__POST_ENTER_IN_ERROR = 40009;
  REMOVE_ALLERGY_COMMAND__PRE_EXECUTE_ACTION = 40010;
  REMOVE_ALLERGY_COMMAND__POST_EXECUTE_ACTION = 40011;
  REMOVE_ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE = 40014;
  REMOVE_ALLERGY_COMMAND__AVAILABLE_ACTIONS = 40015;
  REMOVE_ALLERGY__ALLERGY__PRE_SEARCH = 40012;
  REMOVE_ALLERGY__ALLERGY__POST_SEARCH = 40013;

  RESOLVE_CONDITION_COMMAND__PRE_ORIGINATE = 41000;
  RESOLVE_CONDITION_COMMAND__POST_ORIGINATE = 41001;
  RESOLVE_CONDITION_COMMAND__PRE_UPDATE = 41002;
  RESOLVE_CONDITION_COMMAND__POST_UPDATE = 41003;
  RESOLVE_CONDITION_COMMAND__PRE_COMMIT = 41004;
  RESOLVE_CONDITION_COMMAND__POST_COMMIT = 41005;
  RESOLVE_CONDITION_COMMAND__PRE_DELETE = 41006;
  RESOLVE_CONDITION_COMMAND__POST_DELETE = 41007;
  RESOLVE_CONDITION_COMMAND__PRE_ENTER_IN_ERROR = 41008;
  RESOLVE_CONDITION_COMMAND__POST_ENTER_IN_ERROR = 41009;
  RESOLVE_CONDITION_COMMAND__PRE_EXECUTE_ACTION = 41010;
  RESOLVE_CONDITION_COMMAND__POST_EXECUTE_ACTION = 41011;
  RESOLVE_CONDITION_COMMAND__POST_INSERTED_INTO_NOTE = 41014;
  RESOLVE_CONDITION_COMMAND__AVAILABLE_ACTIONS = 41015;
  RESOLVE_CONDITION__CONDITION__PRE_SEARCH = 41012;
  RESOLVE_CONDITION__CONDITION__POST_SEARCH = 41013;

  ROS_COMMAND__PRE_ORIGINATE = 42000;
  ROS_COMMAND__POST_ORIGINATE = 42001;
  ROS_COMMAND__PRE_UPDATE = 42002;
  ROS_COMMAND__POST_UPDATE = 42003;
  ROS_COMMAND__PRE_COMMIT = 42004;
  ROS_COMMAND__POST_COMMIT = 42005;
  ROS_COMMAND__PRE_DELETE = 42006;
  ROS_COMMAND__POST_DELETE = 42007;
  ROS_COMMAND__PRE_ENTER_IN_ERROR = 42008;
  ROS_COMMAND__POST_ENTER_IN_ERROR = 42009;
  ROS_COMMAND__PRE_EXECUTE_ACTION = 42010;
  ROS_COMMAND__POST_EXECUTE_ACTION = 42011;
  ROS_COMMAND__POST_INSERTED_INTO_NOTE = 42014;
  ROS_COMMAND__AVAILABLE_ACTIONS = 42015;
  ROS__QUESTIONNAIRE__PRE_SEARCH = 42012;
  ROS__QUESTIONNAIRE__POST_SEARCH = 42013;


  SNOOZE_PROTOCOL_COMMAND__PRE_ORIGINATE = 43000;
  SNOOZE_PROTOCOL_COMMAND__POST_ORIGINATE = 43001;
  SNOOZE_PROTOCOL_COMMAND__PRE_UPDATE = 43002;
  SNOOZE_PROTOCOL_COMMAND__POST_UPDATE = 43003;
  SNOOZE_PROTOCOL_COMMAND__PRE_COMMIT = 43004;
  SNOOZE_PROTOCOL_COMMAND__POST_COMMIT = 43005;
  SNOOZE_PROTOCOL_COMMAND__PRE_DELETE = 43006;
  SNOOZE_PROTOCOL_COMMAND__POST_DELETE = 43007;
  SNOOZE_PROTOCOL_COMMAND__PRE_ENTER_IN_ERROR = 43008;
  SNOOZE_PROTOCOL_COMMAND__POST_ENTER_IN_ERROR = 43009;
  SNOOZE_PROTOCOL_COMMAND__PRE_EXECUTE_ACTION = 43010;
  SNOOZE_PROTOCOL_COMMAND__POST_EXECUTE_ACTION = 43011;
  SNOOZE_PROTOCOL_COMMAND__POST_INSERTED_INTO_NOTE = 43014;
  SNOOZE_PROTOCOL_COMMAND__AVAILABLE_ACTIONS = 43015;
  SNOOZE_PROTOCOL__PROTOCOL__PRE_SEARCH = 43012;
  SNOOZE_PROTOCOL__PROTOCOL__POST_SEARCH = 43013;

  STOP_MEDICATION_COMMAND__PRE_ORIGINATE = 44000;
  STOP_MEDICATION_COMMAND__POST_ORIGINATE = 44001;
  STOP_MEDICATION_COMMAND__PRE_UPDATE = 44002;
  STOP_MEDICATION_COMMAND__POST_UPDATE = 44003;
  STOP_MEDICATION_COMMAND__PRE_COMMIT = 44004;
  STOP_MEDICATION_COMMAND__POST_COMMIT = 44005;
  STOP_MEDICATION_COMMAND__PRE_DELETE = 44006;
  STOP_MEDICATION_COMMAND__POST_DELETE = 44007;
  STOP_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR = 44008;
  STOP_MEDICATION_COMMAND__POST_ENTER_IN_ERROR = 44009;
  STOP_MEDICATION_COMMAND__PRE_EXECUTE_ACTION = 44010;
  STOP_MEDICATION_COMMAND__POST_EXECUTE_ACTION = 44011;
  STOP_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE = 44015;
  STOP_MEDICATION_COMMAND__AVAILABLE_ACTIONS = 44012;
  STOP_MEDICATION__MEDICATION__PRE_SEARCH = 44013;
  STOP_MEDICATION__MEDICATION__POST_SEARCH = 44014;

  STRUCTURED_ASSESSMENT_COMMAND__PRE_ORIGINATE = 45000;
  STRUCTURED_ASSESSMENT_COMMAND__POST_ORIGINATE = 45001;
  STRUCTURED_ASSESSMENT_COMMAND__PRE_UPDATE = 45002;
  STRUCTURED_ASSESSMENT_COMMAND__POST_UPDATE = 45003;
  STRUCTURED_ASSESSMENT_COMMAND__PRE_COMMIT = 45004;
  STRUCTURED_ASSESSMENT_COMMAND__POST_COMMIT = 45005;
  STRUCTURED_ASSESSMENT_COMMAND__PRE_DELETE = 45006;
  STRUCTURED_ASSESSMENT_COMMAND__POST_DELETE = 45007;
  STRUCTURED_ASSESSMENT_COMMAND__PRE_ENTER_IN_ERROR = 45008;
  STRUCTURED_ASSESSMENT_COMMAND__POST_ENTER_IN_ERROR = 45009;
  STRUCTURED_ASSESSMENT_COMMAND__PRE_EXECUTE_ACTION = 45010;
  STRUCTURED_ASSESSMENT_COMMAND__POST_EXECUTE_ACTION = 45011;
  STRUCTURED_ASSESSMENT_COMMAND__POST_INSERTED_INTO_NOTE = 45014;
  STRUCTURED_ASSESSMENT_COMMAND__AVAILABLE_ACTIONS = 45015;
  STRUCTURED_ASSESSMENT__QUESTIONNAIRE__PRE_SEARCH = 45012;
  STRUCTURED_ASSESSMENT__QUESTIONNAIRE__POST_SEARCH = 45013;

  SURGICAL_HISTORY_COMMAND__PRE_ORIGINATE = 46000;
  SURGICAL_HISTORY_COMMAND__POST_ORIGINATE = 46001;
  SURGICAL_HISTORY_COMMAND__PRE_UPDATE = 46002;
  SURGICAL_HISTORY_COMMAND__POST_UPDATE = 46003;
  SURGICAL_HISTORY_COMMAND__PRE_COMMIT = 46004;
  SURGICAL_HISTORY_COMMAND__POST_COMMIT = 46005;
  SURGICAL_HISTORY_COMMAND__PRE_DELETE = 46006;
  SURGICAL_HISTORY_COMMAND__POST_DELETE = 46007;
  SURGICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR = 46008;
  SURGICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR = 46009;
  SURGICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION = 46010;
  SURGICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION = 46011;
  SURGICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE = 46014;
  SURGICAL_HISTORY_COMMAND__AVAILABLE_ACTIONS = 46015;
  SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__PRE_SEARCH = 46012;
  SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__POST_SEARCH = 46013;

  TASK_COMMAND__PRE_ORIGINATE = 47000;
  TASK_COMMAND__POST_ORIGINATE = 47001;
  TASK_COMMAND__PRE_UPDATE = 47002;
  TASK_COMMAND__POST_UPDATE = 47003;
  TASK_COMMAND__PRE_COMMIT = 47004;
  TASK_COMMAND__POST_COMMIT = 47005;
  TASK_COMMAND__PRE_DELETE = 47006;
  TASK_COMMAND__POST_DELETE = 47007;
  TASK_COMMAND__PRE_ENTER_IN_ERROR = 47008;
  TASK_COMMAND__POST_ENTER_IN_ERROR = 47009;
  TASK_COMMAND__PRE_EXECUTE_ACTION = 47010;
  TASK_COMMAND__POST_EXECUTE_ACTION = 47011;
  TASK_COMMAND__POST_INSERTED_INTO_NOTE = 47016;
  TASK_COMMAND__AVAILABLE_ACTIONS = 47017;
  TASK__ASSIGN_TO__PRE_SEARCH = 47012;
  TASK__ASSIGN_TO__POST_SEARCH = 47013;
  TASK__LABELS__PRE_SEARCH = 47014;
  TASK__LABELS__POST_SEARCH = 47015;

  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__PRE_ORIGINATE = 48000;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__POST_ORIGINATE = 48001;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__PRE_UPDATE = 48002;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__POST_UPDATE = 48003;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__PRE_COMMIT = 48004;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__POST_COMMIT = 48005;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__PRE_DELETE = 48006;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__POST_DELETE = 48007;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__PRE_ENTER_IN_ERROR = 48008;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__POST_ENTER_IN_ERROR = 48009;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__PRE_EXECUTE_ACTION = 48010;
  // UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND__POST_EXECUTE_ACTION = 48011;

  UPDATE_DIAGNOSIS_COMMAND__PRE_ORIGINATE = 49000;
  UPDATE_DIAGNOSIS_COMMAND__POST_ORIGINATE = 49001;
  UPDATE_DIAGNOSIS_COMMAND__PRE_UPDATE = 49002;
  UPDATE_DIAGNOSIS_COMMAND__POST_UPDATE = 49003;
  UPDATE_DIAGNOSIS_COMMAND__PRE_COMMIT = 49004;
  UPDATE_DIAGNOSIS_COMMAND__POST_COMMIT = 49005;
  UPDATE_DIAGNOSIS_COMMAND__PRE_DELETE = 49006;
  UPDATE_DIAGNOSIS_COMMAND__POST_DELETE = 49007;
  UPDATE_DIAGNOSIS_COMMAND__PRE_ENTER_IN_ERROR = 49008;
  UPDATE_DIAGNOSIS_COMMAND__POST_ENTER_IN_ERROR = 49009;
  UPDATE_DIAGNOSIS_COMMAND__PRE_EXECUTE_ACTION = 49010;
  UPDATE_DIAGNOSIS_COMMAND__POST_EXECUTE_ACTION = 49011;
  UPDATE_DIAGNOSIS_COMMAND__POST_INSERTED_INTO_NOTE = 49016;
  UPDATE_DIAGNOSIS_COMMAND__AVAILABLE_ACTIONS = 49017;
  UPDATE_DIAGNOSIS__CONDITION__PRE_SEARCH = 49012;
  UPDATE_DIAGNOSIS__CONDITION__POST_SEARCH = 49013;
  UPDATE_DIAGNOSIS__NEW_CONDITION__PRE_SEARCH = 49014;
  UPDATE_DIAGNOSIS__NEW_CONDITION__POST_SEARCH = 49015;

  UPDATE_GOAL_COMMAND__PRE_ORIGINATE = 50000;
  UPDATE_GOAL_COMMAND__POST_ORIGINATE = 50001;
  UPDATE_GOAL_COMMAND__PRE_UPDATE = 50002;
  UPDATE_GOAL_COMMAND__POST_UPDATE = 50003;
  UPDATE_GOAL_COMMAND__PRE_COMMIT = 50004;
  UPDATE_GOAL_COMMAND__POST_COMMIT = 50005;
  UPDATE_GOAL_COMMAND__PRE_DELETE = 50006;
  UPDATE_GOAL_COMMAND__POST_DELETE = 50007;
  UPDATE_GOAL_COMMAND__PRE_ENTER_IN_ERROR = 50008;
  UPDATE_GOAL_COMMAND__POST_ENTER_IN_ERROR = 50009;
  UPDATE_GOAL_COMMAND__PRE_EXECUTE_ACTION = 50010;
  UPDATE_GOAL_COMMAND__POST_EXECUTE_ACTION = 50011;
  UPDATE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE = 50012;
  UPDATE_GOAL_COMMAND__AVAILABLE_ACTIONS = 50015;
  UPDATE_GOAL__GOAL_STATEMENT__PRE_SEARCH = 50013;
  UPDATE_GOAL__GOAL_STATEMENT__POST_SEARCH = 50014;

  // VISUAL_EXAM_FINDING_COMMAND__PRE_ORIGINATE = 51000;
  // VISUAL_EXAM_FINDING_COMMAND__POST_ORIGINATE = 51001;
  // VISUAL_EXAM_FINDING_COMMAND__PRE_UPDATE = 51002;
  // VISUAL_EXAM_FINDING_COMMAND__POST_UPDATE = 51003;
  // VISUAL_EXAM_FINDING_COMMAND__PRE_COMMIT = 51004;
  // VISUAL_EXAM_FINDING_COMMAND__POST_COMMIT = 51005;
  // VISUAL_EXAM_FINDING_COMMAND__PRE_DELETE = 51006;
  // VISUAL_EXAM_FINDING_COMMAND__POST_DELETE = 51007;
  // VISUAL_EXAM_FINDING_COMMAND__PRE_ENTER_IN_ERROR = 51008;
  // VISUAL_EXAM_FINDING_COMMAND__POST_ENTER_IN_ERROR = 51009;
  // VISUAL_EXAM_FINDING_COMMAND__PRE_EXECUTE_ACTION = 51010;
  // VISUAL_EXAM_FINDING_COMMAND__POST_EXECUTE_ACTION = 51011;

  VITALS_COMMAND__PRE_ORIGINATE = 52000;
  VITALS_COMMAND__POST_ORIGINATE = 52001;
  VITALS_COMMAND__PRE_UPDATE = 52002;
  VITALS_COMMAND__POST_UPDATE = 52003;
  VITALS_COMMAND__PRE_COMMIT = 52004;
  VITALS_COMMAND__POST_COMMIT = 52005;
  VITALS_COMMAND__PRE_DELETE = 52006;
  VITALS_COMMAND__POST_DELETE = 52007;
  VITALS_COMMAND__PRE_ENTER_IN_ERROR = 52008;
  VITALS_COMMAND__POST_ENTER_IN_ERROR = 52009;
  VITALS_COMMAND__PRE_EXECUTE_ACTION = 52010;
  VITALS_COMMAND__POST_EXECUTE_ACTION = 52011;
  VITALS_COMMAND__POST_INSERTED_INTO_NOTE = 52012;
  VITALS_COMMAND__AVAILABLE_ACTIONS = 52013;

  ASSESS_CODING_GAP_COMMAND__PRE_ORIGINATE = 57000;
  ASSESS_CODING_GAP_COMMAND__POST_ORIGINATE = 57001;
  ASSESS_CODING_GAP_COMMAND__PRE_UPDATE = 57002;
  ASSESS_CODING_GAP_COMMAND__POST_UPDATE = 57003;
  ASSESS_CODING_GAP_COMMAND__PRE_COMMIT = 57004;
  ASSESS_CODING_GAP_COMMAND__POST_COMMIT = 57005;
  ASSESS_CODING_GAP_COMMAND__PRE_DELETE = 57006;
  ASSESS_CODING_GAP_COMMAND__POST_DELETE = 57007;
  ASSESS_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR = 57008;
  ASSESS_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR = 57009;
  ASSESS_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION = 57010;
  ASSESS_CODING_GAP_COMMAND__POST_EXECUTE_ACTION = 57011;
  ASSESS_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE = 57014;
  ASSESS_CODING_GAP_COMMAND__AVAILABLE_ACTIONS = 57015;
  ASSESS_CODING_GAP__DIAGNOSE__PRE_SEARCH = 57012;
  ASSESS_CODING_GAP__DIAGNOSE__POST_SEARCH = 57013;

  CREATE_CODING_GAP_COMMAND__PRE_ORIGINATE = 58000;
  CREATE_CODING_GAP_COMMAND__POST_ORIGINATE = 58001;
  CREATE_CODING_GAP_COMMAND__PRE_UPDATE = 58002;
  CREATE_CODING_GAP_COMMAND__POST_UPDATE = 58003;
  CREATE_CODING_GAP_COMMAND__PRE_COMMIT = 58004;
  CREATE_CODING_GAP_COMMAND__POST_COMMIT = 58005;
  CREATE_CODING_GAP_COMMAND__PRE_DELETE = 58006;
  CREATE_CODING_GAP_COMMAND__POST_DELETE = 58007;
  CREATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR = 58008;
  CREATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR = 58009;
  CREATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION = 58010;
  CREATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION = 58011;
  CREATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE = 58014;
  CREATE_CODING_GAP_COMMAND__AVAILABLE_ACTIONS = 58015;
  CREATE_CODING_GAP__DIAGNOSE__PRE_SEARCH = 58012;
  CREATE_CODING_GAP__DIAGNOSE__POST_SEARCH = 58013;

  VALIDATE_CODING_GAP_COMMAND__PRE_ORIGINATE = 59000;
  VALIDATE_CODING_GAP_COMMAND__POST_ORIGINATE = 59001;
  VALIDATE_CODING_GAP_COMMAND__PRE_UPDATE = 59002;
  VALIDATE_CODING_GAP_COMMAND__POST_UPDATE = 59003;
  VALIDATE_CODING_GAP_COMMAND__PRE_COMMIT = 59004;
  VALIDATE_CODING_GAP_COMMAND__POST_COMMIT = 59005;
  VALIDATE_CODING_GAP_COMMAND__PRE_DELETE = 59006;
  VALIDATE_CODING_GAP_COMMAND__POST_DELETE = 59007;
  VALIDATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR = 59008;
  VALIDATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR = 59009;
  VALIDATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION = 59010;
  VALIDATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION = 59011;
  VALIDATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE = 59012;
  VALIDATE_CODING_GAP_COMMAND__AVAILABLE_ACTIONS = 59013;

  DEFER_CODING_GAP_COMMAND__PRE_ORIGINATE = 60000;
  DEFER_CODING_GAP_COMMAND__POST_ORIGINATE = 60001;
  DEFER_CODING_GAP_COMMAND__PRE_UPDATE = 60002;
  DEFER_CODING_GAP_COMMAND__POST_UPDATE = 60003;
  DEFER_CODING_GAP_COMMAND__PRE_COMMIT = 60004;
  DEFER_CODING_GAP_COMMAND__POST_COMMIT = 60005;
  DEFER_CODING_GAP_COMMAND__PRE_DELETE = 60006;
  DEFER_CODING_GAP_COMMAND__POST_DELETE = 60007;
  DEFER_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR = 60008;
  DEFER_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR = 60009;
  DEFER_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION = 60010;
  DEFER_CODING_GAP_COMMAND__POST_EXECUTE_ACTION = 60011;
  DEFER_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE = 60012;
  DEFER_CODING_GAP_COMMAND__AVAILABLE_ACTIONS = 60013;

  CHANGE_MEDICATION_COMMAND__PRE_ORIGINATE = 61000;
  CHANGE_MEDICATION_COMMAND__POST_ORIGINATE = 61001;
  CHANGE_MEDICATION_COMMAND__PRE_UPDATE = 61002;
  CHANGE_MEDICATION_COMMAND__POST_UPDATE = 61003;
  CHANGE_MEDICATION_COMMAND__PRE_COMMIT = 61004;
  CHANGE_MEDICATION_COMMAND__POST_COMMIT = 61005;
  CHANGE_MEDICATION_COMMAND__PRE_DELETE = 61006;
  CHANGE_MEDICATION_COMMAND__POST_DELETE = 61007;
  CHANGE_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR = 61008;
  CHANGE_MEDICATION_COMMAND__POST_ENTER_IN_ERROR = 61009;
  CHANGE_MEDICATION_COMMAND__PRE_EXECUTE_ACTION = 61010;
  CHANGE_MEDICATION_COMMAND__POST_EXECUTE_ACTION = 61011;
  CHANGE_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE = 61012;
  CHANGE_MEDICATION_COMMAND__AVAILABLE_ACTIONS = 61015;
  CHANGE_MEDICATION__MEDICATION__PRE_SEARCH = 61013;
  CHANGE_MEDICATION__MEDICATION__POST_SEARCH = 61014;

  SHOW_NOTE_HEADER_BUTTON = 70000;
  SHOW_NOTE_FOOTER_BUTTON = 70001;
  ACTION_BUTTON_CLICKED = 70002;

  PATIENT_CHART__CONDITIONS = 100000;
  PATIENT_CHART__DETECTED_ISSUES = 100005;

  PATIENT_CHART_SUMMARY__SECTION_CONFIGURATION = 100001;

  PATIENT_PROFILE__SECTION_CONFIGURATION = 100002;
  PATIENT_PROFILE__ADD_PHARMACY__POST_SEARCH = 100003;

  PATIENT_CHART__MEDICATIONS = 100004;
  CLAIM__CONDITIONS = 101000;

  PLUGIN_CREATED = 102000;
  PLUGIN_UPDATED = 102001;

  APPLICATION__ON_OPEN = 103000;
  APPLICATION__ON_CONTEXT_CHANGE = 103001;

  PATIENT_PORTAL__GET_FORMS = 110000;
  PATIENT_PORTAL__APPOINTMENT_CANCELED = 110001;
  PATIENT_PORTAL__APPOINTMENT_RESCHEDULED = 110002;
  PATIENT_PORTAL__APPOINTMENT_CAN_BE_CANCELED = 110003;
  PATIENT_PORTAL__APPOINTMENT_CAN_BE_RESCHEDULED = 110004;
  PATIENT_PORTAL__APPOINTMENTS__SLOTS__POST_SEARCH = 110005;
  PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__PRE_SEARCH = 110006;
  PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__POST_SEARCH = 110007;
  PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__PRE_SEARCH = 110008;
  PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__POST_SEARCH = 110009;
  PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__PRE_SEARCH = 110010;
  PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__POST_SEARCH = 110011;
  PATIENT_PORTAL__APPOINTMENT_CAN_SHOW_MEETING_LINK = 110012;
  PATIENT_PORTAL__GET_APPLICATION_CONFIGURATION = 110013;

  PATIENT_PORTAL__MENU_CONFIGURATION = 110100;
  PATIENT_PORTAL__WIDGET_CONFIGURATION = 110101;

  SHOW_CHART_SUMMARY_SOCIAL_DETERMINANTS_SECTION_BUTTON = 120000;
  SHOW_CHART_SUMMARY_GOALS_SECTION_BUTTON = 120001;
  SHOW_CHART_SUMMARY_CONDITIONS_SECTION_BUTTON = 120002;
  SHOW_CHART_SUMMARY_MEDICATIONS_SECTION_BUTTON = 120003;
  SHOW_CHART_SUMMARY_ALLERGIES_SECTION_BUTTON = 120004;
  SHOW_CHART_SUMMARY_CARE_TEAMS_SECTION_BUTTON = 120005;
  SHOW_CHART_SUMMARY_VITALS_SECTION_BUTTON = 120006;
  SHOW_CHART_SUMMARY_IMMUNIZATIONS_SECTION_BUTTON = 120007;
  SHOW_CHART_SUMMARY_SURGICAL_HISTORY_SECTION_BUTTON = 120008;
  SHOW_CHART_SUMMARY_FAMILY_HISTORY_SECTION_BUTTON = 120009;
  SHOW_CHART_SUMMARY_CODING_GAPS_SECTION_BUTTON = 120010;

  SIMPLE_API_AUTHENTICATE = 130000;
  SIMPLE_API_REQUEST = 130001;
  SIMPLE_API_WEBSOCKET_AUTHENTICATE = 130002;

  PATIENT_METADATA__GET_ADDITIONAL_FIELDS = 140000;

  PATIENT_EXTERNAL_IDENTIFIER_CREATED = 140001;
  PATIENT_EXTERNAL_IDENTIFIER_UPDATED = 140002;
  PATIENT_EXTERNAL_IDENTIFIER_DELETED = 140003;
  PATIENT_METADATA_CREATED = 140004;
  PATIENT_METADATA_UPDATED = 140005;

  APPOINTMENT__FORM__PROVIDERS__PRE_SEARCH = 141000;
  APPOINTMENT__FORM__LOCATIONS__PRE_SEARCH = 141001;
  APPOINTMENT__FORM__VISIT_TYPES__PRE_SEARCH = 141002;
  APPOINTMENT__FORM__DURATIONS__PRE_SEARCH = 141003;
  APPOINTMENT__FORM__REASON_FOR_VISIT__PRE_SEARCH = 141004;

  APPOINTMENT__FORM__PROVIDERS__POST_SEARCH = 141006;
  APPOINTMENT__FORM__LOCATIONS__POST_SEARCH = 141007;
  APPOINTMENT__FORM__VISIT_TYPES__POST_SEARCH = 141008;
  APPOINTMENT__FORM__DURATIONS__POST_SEARCH = 141009;
  APPOINTMENT__FORM__REASON_FOR_VISIT__POST_SEARCH = 141010;

  APPOINTMENT__FORM__GET_ADDITIONAL_FIELDS = 141011;

  APPOINTMENT__SLOTS__POST_SEARCH = 141012;

  APPOINTMENT_METADATA_CREATED = 141100;
  APPOINTMENT_METADATA_UPDATED = 141111;

  DOCUMENT_REFERENCE_CREATED = 150000;
  DOCUMENT_REFERENCE_UPDATED = 150001;
  DOCUMENT_REFERENCE_DELETED = 150002;

  PANEL_SECTIONS_CONFIGURATION = 15100;

  REVENUE__PAYMENT_PROCESSOR__LIST = 160001;
  REVENUE__PAYMENT_PROCESSOR__CHARGE = 160003;
  REVENUE__PAYMENT_PROCESSOR__SELECTED = 160002;
  REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHODS__LIST = 160004;
  REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHODS__ADD = 160005;
  REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHODS__REMOVE = 160006;
}

message Event {
  EventType type = 1;
  // Oneof target = 2 {
  //
  // }
  string target = 2;
  string context = 3;
  string target_type = 4;
}

message EventResponse {
  bool success = 1;
  repeated Effect effects = 2;
}
