from canvas_generated.messages import events_pb2 as _events_pb2
from canvas_generated.messages import plugins_pb2 as _plugins_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
