from canvas_cli.apps.plugin.plugin import (
    disable,
    enable,
    init,
    install,
    list,
    list_secrets,
    set_secrets,
    uninstall,
    validate_manifest,
)

__all__ = (
    "list_secrets",
    "set_secrets",
    "disable",
    "enable",
    "init",
    "install",
    "list",
    "uninstall",
    "validate_manifest",
)
